/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     File "include/automaton.h"           */
/*  Constants and definitions for automatons handling.                       */
/*                                                                           */
/*  Author : JYA/FA                     Last modification : 2018/08/18       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations =======================================================


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures


*/


#ifndef AUTOMATON_H                    /* If this file is not already        */
#define AUTOMATON_H                    /* included, include it.              */


/*
    1    Defines
    ____________
  

         Ce fichier contient les definitions des numeros d'automates, ainsi que
celles des numeros d'evenements. On a actuellement deux "tranches" de numeros
d'automates :

   - Les numeros 0 a 127 sont ceux des automates du VMOS, c'est-a-dire des
     automates executes par "moteur.c"

   - Les numeros 128 a 255 sont ceux des automates du VMIO, c'est-a-dire des
     automates executes par "motrit.c". L'automate numero 128 est TOUJOURS
     et ETERNELLEMENT reserve a AUT_RESOLVE.


         Les numeros des automates du VMOS servent d'indice dans les  trois
tables "anom", "enom" et "nnom" situees dans vmos/vmk2.c. A chaque fois que
l'on ajoute, retire un automate, ou que l'on change les valeurs des numeros, il
faut modifier ces trois tables en consequence. Si on ne le fait pas, non
seulement les traces du moteur sont fausses, mais en plus on peut generer des
ecrasements memoire. Les "tranches" de numeros d'evenements sont les suivantes:

   - Les evenements de 0 a 299 sont des codes utilisables en PanTalk, ils
     possedent des menemoniques. Ces codes sont definis dans "engine.h". On
     y trouve les codes "generaux" du VMOS, ainsi que les codes "generaux" du
     VMIO.

   - Les evenements de 300 a 499 sont les codes "generaux" du VMIO. Ils sont
     definis dans "engine.h". Ils possedent des mnemoniques, aux cas ou
     certains "remontent" jusqu'au VMOS. Mais la majorite de ces mnemoniques
     ne seront jamais utilises.

   - Les evenements a partir de 1024 sont les codes d'evenements "prives" des
     automates du VMOS. Ces codes sont definis dans le present fichier, ce qui
     signifie qu'ils ne sont pas des mnemoniques Pantalk, comme le sont les
     code de "engine.h". Par convention, on reserve pour chaque automate
     du VMOS une trance de 32 numeros consecutifs. La premiere tranche ainsi
     reservee est la tranche 1024 a 1024+31 = 1055, et est attribuee a 
     l'automate "script" AUTSCR_EXE (0)

   - Les evenements de code superieur ou egal a 10000 sont reserves aux 
     applications PanTalk. Les codes d'evenements etant des USHORT, la plus
     grande valeur est 32767. Les codes negatifs sont interdits.

*** Les codes des evenements TO_ devraient etre des codes "locaux, definis
    dans "automaton.h" et pas ici.

***  PENSEZ A TENIR A JOUR VMK2.C
*/

#define ALL_EVENT           -1         /* N'importe quel evenement           */


/*****************************************************************************
 * Numeros des automates du VMOS                                             *
 * -----------------------------                                             *
 *                                                                           *
 * Ces numeros d'automates sont compris entre 0 et 127                       *
 *                                                                           *
 * Pour chaque numero d'automate, on trouve a la suite les codes de ses      *
 * evenements "prives". Le premier de ces codes est toujours egal a          *
 * 1024 + 32 * numero de l'automate. De ce fait, on dispose de 32 codes      *
 * pour chacun des automates                                                 *
 *                                                                           *
 *****************************************************************************/


/*****************************************************************************
 * Procedure "timerto" : Pour permettre la purge sans risque d'erreur des    *
 * TO, une valeur particuliere des champs "emet" des evenements est reservee *
 * aux TO du VMK. Il s'agit de la valeur 0.                                  *
 *****************************************************************************/

#define TIMERTO               0        /* vmos/mosteur/vmk1.c, timerto"      */


/* Automate Interpreteur de Scripts .........................................*/

#define AUTSCR_EXE            1        /* src/executif/scr_auto.c            */
                                       /* Evenements prives:                 */
#define SCR_EXE_CONT       1056        /* code evt script -> execution       */
#define SCR_EXE_BREAK      1057        /* code evt script -> interruption    */
#define CND_EXE_LOAD       1058        /* condition script -> chargement     */
#define SCR_EXE_SCHED      1059        /* code evt script -> scheduler       */


/* Automates claviers ...................................................... */

#define AUTTKBD               2        /* src/moteur/autkbd.c                */
                                       /* Evenements prives:                 */
#define KEY_TEMPO          1088        /* Evt de temporisation.              */
                                       /*                                    */
#define AUTKBD                3        /* src/moteur/autkbd.c                */
                                       /* Evenements prives:                 */
#define KEY_RELEASE_R      1120        /* Touche relachee                    */


/* Automate de gestion des evenements souris ................................*/

#define AUTMOUSE              4        /* src/moteur/autmse.c                */
                                       /* Evenements prives:                 */
#define MOUSE_TEMPO        1152        /* Evt fin de tempo.                  */
#define MOUSE_INIT         1153        /* Evt 1er pression sur bouton souris */
#define MOUSE_STOP         1154        /* Evt retour a l'etat 0.             */
#define MOUSE_BREAK        1155        /* Evt attente de fin de move_cursor()*/
#define MOUSE_RETURN       1156        /* Evt fin du move_cursor().          */
 

/* Automate TIME ............................................................*/

#define AUT_TIME              5        /* src/moteur/auttime.c               */
                                       /*                                    */
#define TIME_WATCHDOG      1184        /*                                    */


/* Automate de gestion du chargement ........................................*/

#define AUTHLOAD              6        /* src/memoire/setelt.c               */
                                       /* Evenements prives:                 */
#define HLOAD_LOAD         1216        /* Lancer      le chargement          */
#define HLOAD_DOWNLOAD     1217        /* Attendre    le telechargement      */
#define HLOAD_SOLVE_REF    1218        /* Attendre    le chargement des ref. */
#define HLOAD_INIT         1219        /* Attendre    l'initialisation       */
#define HLOAD_WAIT_LOAD    1220        /* Attendre    le passage a utilisable*/
#define HLOAD_ERROR        1221        /* Erreur      de chargement          */
#define HLOAD_CONT         1222        /* Continuer   le chargement          */
#define HLOAD_WAIT         1223        /* Interrompre le chargement          */
#define HLOAD_CHECK_EXE    1224        /* Verifier    si executable          */


/* Automate de gestion des telechargements ..................................*/

#define AUT_DOWNLOAD          7        /* src/file/download.c                */
                                       /* Evenements prives:                 */
#define BLOC_RECEIVED      1248        /* Bloc recu                          */
#define VOLUME_CHANGE      1249        /* Volume a change                    */
#define VOLUME_END         1250        /* Volume n'est plus diffuse          */
#define DOWNLOAD_ERROR     1251        /* Erreur de chargement               */
#define DOWNLOAD_CONT      1252        /* Continuer un autre chargement      */


/* Automate telechargement MHEG5, base sur DSMCC ............................*/

#define AUT_DSMCC_MPEG2       8        /* src/file/dsmcc.c                   */
                                       /* Evenements prives:                 */
#define MHEG_TIMEOUT       1280        /* Fin de tempo sur reception         */
#define MHEG_ERROR         1281        /* Erreur dans ce qui a ete recu      */
#define MHEG_FIL_FOUND     1282        /* Fin de la recherche                */
#define MHEG_DII_FOUND     1283        /* Fin de demande de DII              */
#define MHEG_WAIT          1284        /* Attente de fin d'un autre chargt   */
#define DSMCC_SETDMX       1285        /* Commande de configuartion demux.   */
#define C_DSMCC_LIB        1286        /* Condition: liberer le filtre demux */
#define C_DSMCC_ERROR      1287        /* Condition: erreur allocation filtre*/
                                       /*                                    */

/* Automate vide ............................................................*/

#define AUT_EMPTY             9        /*                                    */


/* Automates DF ............................................................ */

#define AUT_DF               10        /* src/file/df.c                      */


/* Automate AUT_TASK ....................................................... */

#define AUT_TASK             11        /* vmos/moteur/vmk.c                  */
                                       /*                                    */
#define RUN_TASK           1376        /* Lance une tache.                   */
#define KILL_TASK          1377        /* Tue   une tache.                   */
#define CLOSE_TASK         1378        /* Fin d'une tache.                   */
#define TASK_TIMER         1379        /* Echeance d'un timer de tache.      */
#define TASK_SIGNAL        1380        /* Un semaphore devient disponible.   */
#define TASK_EVT0          1381        /* 1er   evenement inter-taches.      */
#define TASK_EVT1          1382        /* 2nd   evenement inter-taches.      */
#define TASK_EVT2          1383        /* 3eme  evenement inter-taches.      */
#define TASK_EVT3          1384        /* 4eme  evenement inter-taches.      */
#define TASK_EVT4          1385        /* 5eme  evenement inter-taches.      */
#define TASK_EVT5          1386        /* 6eme  evenement inter-taches.      */
#define TASK_EVT6          1387        /* 7eme  evenement inter-taches.      */
#define TASK_EVT7          1388        /* 8eme  evenement inter-taches.      */
#define TASK_EVT8          1389        /* 9eme  evenement inter-taches.      */
#define TASK_EVT9          1390        /* 10eme evenement inter-taches.      */
#define TASK_EVT10         1391        /* 11eme evenement inter-taches.      */
#define TASK_EVT11         1392        /* 12eme evenement inter-taches.      */
#define TASK_EVT12         1393        /* 13eme evenement inter-taches.      */
#define TASK_EVT13         1394        /* 14eme evenement inter-taches.      */
#define TASK_EVT14         1395        /* 15eme evenement inter-taches.      */
#define TASK_EVT15         1396        /* 16eme evenement inter-taches.      */
#define TASK_EVT16         1397        /* 17eme evenement inter-taches.      */
#define TASK_EVT17         1398        /* 18eme evenement inter-taches.      */
#define TASK_EVT18         1399        /* 19eme evenement inter-taches.      */
#define TASK_EVT19         1400        /* 20eme evenement inter-taches.      */
#define TASK_EVT20         1401        /* 21eme evenement inter-taches.      */
#define TASK_EVT21         1402        /* 22eme evenement inter-taches.      */
#define TASK_EVT22         1403        /* 23eme evenement inter-taches.      */
#define TASK_EVT23         1404        /* 24eme evenement inter-taches.      */
#define TASK_EVT24         1405        /* 25eme evenement inter-taches.      */
#define TASK_EVT25         1406        /* 26eme evenement inter-taches.      */
#define TASK_EVT26         1407        /* 27eme evenement inter-taches.      */
#define TASK_EVT27         1408        /* 28eme evenement inter-taches.      */
#define TASK_EVT28         1409        /* 29eme evenement inter-taches.      */
#define TASK_EVT29         1410        /* 30eme evenement inter-taches.      */
#define TASK_EVT30         1411        /* 31eme evenement inter-taches.      */
#define TASK_EVT31         1412        /* 32eme evenement inter-taches.      */


/* Automate de gestion de la tables des ON en V3 ............................*/

#define AUT_PTLKV3           12        /* numero automate                    */
                                       /*                                    */
#define PTLKV3_OFF         1408        /* Effacement d'un module             */


/* Automate  AUT_DVBSTL des sous-titres DVB .................................*/

#define AUT_DVBSTL           13        /* src/ttx/dvbstl.c                   */
                                       /* (specific old / new)               */

/* Automate de selection de slot de controle d'acces. .......................*/

#define AUT_CA_API           14        /* src/acces/ac_api.c                 */
                                       /*                                    */
#define CA_STM_ON          1472        /* Debut d'utilisation du stream.     */
#define CA_STM_UPD         1473        /* Modification de la PMT.            */
#define CA_STM_OFF         1474        /* Fin d'utilisation du stream.       */
#define CA_STM_STAT        1475        /* Nouveau statut du stream pour le CA*/
#define CA_ACTIVE          1476        /* Module CA externe insere/CA actif. */
#define CA_INACTIVE        1477        /* Module CA extrn retire/CA desactive*/
#define CA_SC_INIT         1478        /* Initialisation d'1 lecteur de carte*/
#define CA_SC_IN           1479        /* Smart Card reconnue (slot CA).     */
#define CA_STM_CLEAR       1480        /* Condition: stream non crypte.      */
#define CA_STM_CRYPT       1481        /* Condition: pas de CA pour decrypter*/
#define CA_USE_EMB         1482        /* Condition: choix d'1 CA embarque.  */
#define CA_USE_UC          1483        /* Condition: choix d'1 CA emb UC.    */
#define CA_USE_EXT         1484        /* Condition: choix d'1 CA externe.   */
#define CA_USE_DEF         1485        /* Condition: choix d'1 CA par defaut.*/
#define CA_STILL           1486        /* Condition: rester dans le meme etat*/
#define CA_POL_NEXT        1487        /* Temporisation de poling des slots. */
#define CA_FORCE_SEL       1488        /* Force a refaire la selection.      */
#define CA_STM_WAIT        1489        /* Attendre encore le status du stream*/
#define CA_STM_TO          1490        /* Fin d'attente de status.           */
#define CA_DEC_TO          1491        /* Fin d'attente de status d'1 decoder*/
#define CA_ASK_DEC         1492        /* Cnd: Attendre le status d'1 decoder*/
#define CA_SC_EVT          1493        /* Cnd: Carte a puce inseree (driver).*/
#define CA_TIMER           1494        /* Timer specifique d'un slot CA.     */
#define CA_SC_CLOSE        1495        /* Arret d'un slot de carte (standby).*/


/* Automate driver pour Viaccess ............................................*/

#define AUT_VA_DRV           15        /* src/acces/va_drv.c                 */
                                       /*                                    */
#define VA_DMX_ALLOC       1504        /* Requete d'allocation d'1 scnl demux*/
#define VA_DMX_SET         1505        /* Requete de configuration d'1 filtre*/
#define VA_DMX_START       1506        /* Requete de demarrage d'1 filtre.   */
#define VA_DMX_STOP        1507        /* Requete d'arret d'1 filtre.        */
#define VA_DMX_FREE        1508        /* Requete de liberation d'1 filtre.  */
#define VA_DMX_SSF         1509        /* Requete de config filtres softwares*/
#define VA_KEY_SET         1510        /* Requete de mise en place de cles.  */
#define VA_KEY_DEL         1511        /* Requete de suppressions de cles.   */
#define VA_SMC_ON          1512        /* Requete de demarrage               */
#define VA_SMC_OFF         1513        /* Requete d'arret                    */
#define VA_SMC_RESET       1514        /* Requete de reset de la carte a puce*/
#define VA_SMC_SEND        1515        /* Requete d'envoi de commande        */
#define VA_SMC_ACT         1516        /* Requete d'activation               */
#define VA_SMC_DEACT       1517        /* Requete de desactivation           */
#define VA_SMC_CLOSE       1518        /* Requete de fermeture               */
#define VA_SEC_INFO        1519        /* Requete de lecture UID et Fuse CWK.*/
#define VA_SEC_MODE        1520        /* Requete de config mode CW.         */
#define VA_SEC_FUSE        1521        /* Requete de fusing CWK.             */
#define VA_SEC_CWK         1522        /* Requete de config CWK.             */
#define VA_SEC_DMA         1523        /* Requete de transfert Secure DMA.   */
                                       /*                                    */
#define C_VA_ERROR         1524        /* Cnd: Echec d'une requete.          */
#define C_VA_ERROR2        1525        /* Cnd: Echec d'une requete.          */
#define C_VA_STILL         1526        /* Cnd: Rester dans le meme etat.     */
#define C_VA_SET           1527        /* Cnd: Configurer.                   */
#define C_VA_START         1528        /* Cnd: Demarrer.                     */
#define C_VA_STOP          1529        /* Cnd: Arreter.                      */
#define C_VA_FREE          1530        /* Cnd: Liberer.                      */
#define C_VA_RESET         1531        /* Cnd: Resetter la carte a puce      */
#define C_VA_EMPTY         1532        /* Cnd: Pas/plus de carte.            */
#define C_VA_PTS           1533        /* Cnd: Carte prete pour PTS/T0/T1.   */
#define C_VA_T0            1534        /* Cnd: Carte prete pour T0.          */
#define C_VA_T1            1535        /* Cnd: Carte prete pour T1.          */
#define C_VA_MUTE          1536        /* Cnd: Carte ne repond pas/plus.     */
#define C_VA_SSF           1537        /* Cnd: Reconfig du SSF (filtre SW)   */


/* Automate du VM CAS .......................................................*/

#define AUT_VMCAS            16        /* src/acces/vmcas.c                  */
                                       /* Precedent automate deborde de 2!   */
#define VMC_REQ_INIT       1538        /* Requete d'initialisation de VL.    */
#define VMC_REQ_END        1539        /* Requete d'arret de VL.             */
#define VMC_REQ_WRITE      1540        /* Requete d'ecriture.                */
#define VMC_REQ_SETVAL     1541        /* Requete de configuration           */
#define VMC_RESP_INIT      1542        /* Fin d'initialisation de VL.        */
#define VMC_RESP_END       1543        /* Fin d'arret de VL.                 */
#define VMC_TO             1544        /* Fin de temporisation.              */
#define VMC_DATA           1545        /* Nouvelles donnees recues.          */
#define C_VMC_ERR          1546        /* Cnd: Erreur.                       */
#define C_VMC_ERR2         1547        /* Cnd: Erreur.                       */
#define C_VMC_OK           1548        /* Cnd: Succes.                       */
#define C_VMC_READY        1549        /* Cnd: On a fini.                    */
#define C_VMC_NEXT         1550        /* Cnd: Succes, etape suivante.       */
#define C_VMC_END          1551        /* Cnd: Arret a effectuer.            */


/* Automate interface CA ENIGMA .............................................*/

#define AUT_ES_DRV           17        /* src/acces/es_drv.c                 */
                                       /*                                    */
#define ES_DMX_ALLOC       1568        /* Requete d'allocation d'1 scnl demux*/
#define ES_DMX_SET         1569        /* Requete de configuration d'1 filtre*/
#define ES_DMX_START       1570        /* Requete de demarrage d'1 filtre.   */
#define ES_DMX_STOP        1571        /* Requete d'arret d'1 filtre.        */
#define ES_DMX_FREE        1572        /* Requete de liberation d'1 filtre.  */
#define ES_DMX_SSF         1573        /* Requete de config filtres softwares*/
#define ES_KEY_SET         1574        /* Requete de mise en place de cles.  */
#define ES_KEY_DEL         1575        /* Requete de suppressions de cles.   */
#define ES_NVM_OPEN        1576        /* Requete d'ouverture de fichier.    */
#define ES_NVM_CLOSE       1577        /* Requete de fermeture de fichier.   */
#define ES_NVM_READ        1578        /* Requete de lecture de fichier.     */
#define ES_NVM_WRITE       1579        /* Requete d'ecriture de fichier.     */
#define ES_UID_GET         1580        /* Requete de lecture de l'UID.       */
#define ES_TO              1581        /* Fin de temporisation.              */
#define C_ES_ERR           1582        /* Condition : erreur rencontree.     */
#define C_ES_ERR2          1583        /* Condition : erreur rencontree.     */
#define C_ES_OK            1584        /* Condition : tout s'est bien passe. */
#define C_ES_STOP          1585        /* Condition : arret.                 */
#define C_ES_SET           1586        /* Condition : redemarrage.           */


/* Automate demux/carte/vnm  pour Aladin ....................................*/

#define AUT_ALA_DMX          18        /* scr/acces/ala_dmx.c                */
                                       /*                                    */
#define ALA_DMX_START      1600        /* L'acquisition est lancee.          */
#define ALA_DMX_STOP       1601        /* L'acquisition est arretee.         */
#define ALA_DMX_TO         1602        /* Fin de tempo attente d'acquisition.*/
#define ALA_DMX_STILL      1603        /* Condition: rester dans etat courant*/
                                       /*                                    */
#define AUT_ALA_SC           19        /* src/acces/ala_smc.c                */
                                       /*                                    */
#define ALA_SMC_OFF        1632        /* Acces au slot n'est plus autorise. */
#define ALA_SMC_ON         1633        /* Acces au slot est autorise.        */
#define ALA_SMC_REQ        1634        /* Une requete io est lancee.         */
#define ALA_SMC_RST        1635        /* Un reset a ete demande.            */
#define ALA_SMC_MOD        1636        /* Aladin demande mode=ACCESS_NONE.   */
#define ALA_SMC_STILL      1637        /* Cnd: rester dans l'etat courant.   */
#define ALA_SMC_WERR       1638        /* Cnd: erreur en emission.           */
#define ALA_SMC_PTS        1639        /* Cnd: envoyer une requete PTS.      */
#define ALA_SMC_RWRT       1640        /* Cnd: driver tente de reemettre.    */
                                       /*                                    */
#define AUT_ALA_NVM          20        /* src/acces/ala_nvm.c                */


/* Automate demux/carte pour Conax ..........................................*/

#define AUT_CNX_SMC          21        /* src/acces/cnx_smc.c                */
                                       /*                                    */
#define CNX_SMC_OFF        1696        /* Acces au slot n'est plus autorise. */
#define CNX_SMC_ON         1697        /* Acces au slot est autorise.        */
#define CNX_SMC_REQ        1698        /* Une requete io est lancee.         */
#define CNX_SMC_RST        1699        /* Un reset a ete demande.            */
#define CNX_SMC_STILL      1700        /* Cnd: rester dans l'etat courant.   */
#define CNX_SMC_WERR       1701        /* Cnd: erreur en emission.           */
#define CNX_SMC_RERR       1702        /* Cnd: erreur en reception.          */
#define CNX_SMC_DAT        1703        /* Cnd: donnees a lire dans la carte. */
                                       /*                                    */
#define AUT_CNX_DMX          22        /* src/acces/cnx_dmx.c                */


/* Automate de gestion de requetes pour Conax ...............................*/

#define AUT_CNX_REQ          23        /* src/acces/cnx_req.c                */
                                       /*                                    */
#define CNX_REQ_EXT        1760        /* Extraction de la carte a puce.     */
#define CNX_REQ_INS        1761        /* Insertion d'une carte a puce.      */
#define CNX_REQ_RST        1762        /* Fin de reset de la carte a puce.   */
#define CNX_REQ_END        1763        /* Fin de la requete courante.        */
#define CNX_REQ_INIT_SMC   1764        /* Requete d'initialisation d'une smc.*/
#define CNX_REQ_SEND_CAT   1765        /* Requete d'envoi de la CAT.         */
#define CNX_REQ_SEND_PMT   1766        /* Requete d'envoi de la PMT.         */
#define CNX_REQ_SEND_EMM   1767        /* Requete d'envoi d'un EMM.          */
#define CNX_REQ_SEND_ECM   1768        /* Requete d'envoi d'un ECM.          */
#define CNX_REQ_SEND_STR   1769        /* Requete d'envoi reponse a enquiry. */
#define CNX_REQ_SEND_CHR   1770        /* Requete d'envoi d'un caractere.    */
#define CNX_REQ_OA_SEL     1771        /* Requete d'envoi d'une selection OA.*/
#define CNX_REQ_RELOCK     1772        /* Requete reverrouillage maturity/PPV*/
#define CNX_REQ_CONSULT    1773        /* Requete de consultation de la carte*/
#define CNX_REQ_PINCOM     1774        /* Requete concernant le PIN Code.    */
#define CNX_REQ_RFD        1775        /* Refus de la carte a puce.          */
#define CNX_REQ_STILL      1776        /* Condition: rester dans le meme etat*/
#define CNX_REQ_REINIT     1777        /* Condition: reset de la carte.      */
#define CNX_REQ_ERR        1778        /* Condition: erreur detectee.        */
#define CNX_REQ_RPH        1779        /* Condition: requete vers Return Path*/
#define CNX_REQ_INISESS    1780        /* Condition: initialiser les sessions*/
#define CNX_REQ_READY      1781        /* Condition: carte prete.            */


/* Automate Host pour Conax .................................................*/

#define AUT_CNX_HOST         24        /*                                    */
                                       /*                                    */
#define CNX_HOST_EXT       1792        /* Extraction de la carte a puce.     */
#define CNX_HOST_INS       1793        /* Carte inseree, initialisee et prete*/
#define CNX_HOST_END       1794        /* Fin de la requete courante.        */
#define CNX_HOST_EMM       1795        /* Reception d'un EMM.                */
#define CNX_HOST_ECM       1796        /* Reception d'un ECM.                */
#define CNX_HOST_CAT       1797        /* Transmettre la CAT.                */
#define CNX_HOST_PMT       1798        /* Transmettre la PMT.                */
#define CNX_HOST_CHR       1799        /* Transmettre un choix applicatif.   */
#define CNX_HOST_STR       1800        /* Transmettre une saisie applicative.*/
#define CNX_HOST_RELOCK    1801        /* Transmettre demande reverrouillage.*/
#define CNX_HOST_CONSULT   1802        /* Transmettre requete de consultation*/
#define CNX_HOST_PINCOM    1803        /* Transmettre requete liee o PIN Code*/
#define CNX_HOST_ERR       1804        /* Condition: Pb SMC irrecuperable.   */
#define CNX_HOST_WAIT      1805        /* Condition: aller attendre requete. */
#define CNX_HOST_REINIT    1806        /* Condition: reinitialisation smc.   */


/* Automate Mediaguard ......................................................*/

#define AUT_MG_DRV           25        /*                                    */
                                       /* Demux et filtres.                  */
#define MG_DMX_CBK         1824        /* Evt: Appeler une callback MG.      */
#define MG_DMX_TABLE       1825        /* Evt: Reception d'une table DVB.    */
#define MG_KEY_SET         1826        /* Evt: Modifier les cles de dechiffrt*/
#define MG_FLT_START       1827        /* Evt: Requete MG de demarrage filtre*/
#define MG_FLT_STOP        1828        /* Evt: Requete MG d'arret d'un filtre*/
#define MG_FLT_TO          1829        /* Evt: Time-out d'attente de section.*/
#define MG_FLT_NONE        1830        /* Cnd: Echec d'allocation de filtre. */
#define MG_FLT_FREE        1831        /* Cnd: Liberer le filtre.            */
#define MG_FLT_ALLOC       1832        /* Cnd: Reallouer le filtre.          */
#define MG_FLT_CFG         1833        /* Cnd: Reconfigurer le filtre.       */
                                       /* Carte a puce pour Mediaguard.      */
#define MG_SMC_ON          1834        /* Acces au slot est autorise.        */
#define MG_SMC_OFF         1835        /* Acces au slot n'est plus autorise. */
#define MG_SMC_CLOSE       1836        /* Fermeture du slot (drv_close).     */
#define MG_SMC_RESET       1837        /* Requete de reset du slot.          */
#define MG_SMC_LOCK        1838        /* Requete de verrouillage du slot.   */
#define MG_SMC_UNLOCK      1839        /* Suppression du verrouillage du slot*/
#define MG_SMC_LOCKTO      1840        /* Time-out verrouillage du slot.     */
#define MG_SMC_PTS         1841        /* Requete PTS pour le slot.          */
#define MG_SMC_SEND        1842        /* Requete d'emission pour le slot.   */
#define MG_SMC_SUBSCR      1843        /* Requete d'enregistrement call-back.*/
                                       /* Commentaire                        */
#define C_MG_RESET         1844        /* Cnd: Reset avant PTS pour le slot. */
#define C_MG_OK            1845        /* Cnd: Succes d'un PTS sans negocier.*/
#define C_MG_KO            1846        /* Cnd: Echec d'une requete.          */
#define C_MG_EMPTY         1847        /* Cnd: Pas/plus de carte.            */
#define C_MG_PTS           1848        /* Cnd: Carte prete pour PTS/T0/T1.   */
#define C_MG_T0            1849        /* Cnd: Carte prete pour T0.          */
#define C_MG_T1            1850        /* Cnd: Carte prete pour T1.          */
#define C_MG_MUTE          1851        /* Cnd: Carte ne repond pas/plus.     */
#define C_MG_ERROR         1852        /* Cnd: Erreur de communication smc.  */
#define C_MG_IDLE          1853        /* Cnd: Rester dans le meme etat.     */
                                       /* Evenements Non Volatile Memory     */
#define MG_NVM_WRT         1854        /* Requete MG d'ecriture en NVM.      */
                                       /* Evenements OS                      */
#define MG_OS_TIM          1855        /* Evt: echeance d'un timer MG.       */
#define MG_OS_INHIBIT      1856        /* Evt: echeance d'un timer MG.       */


/* Automate CA pour Mediaguard ..............................................*/

#define AUT_MG_CA            26        /*                                    */
                                       /*                                    */
#define MG_CA_MAT_TO       1856        /* Evt: echeance d'un timer MG.       */
#define MG_CA_PPV_TO       1857        /* Evt: echeance d'un timer MG.       */
#define MG_CA_TST_TO       1858        /* Evt: echeance du timer de test.    */


/* Automate CA DVB-CI .......................................................*/

#define AUT_CI_CA            27        /* "$vmos/acces/dvbci_ca.c"           */
                                       /*                                    */
#define IOD_SET            1888        /* Mise en place de l'IOD protocole   */
#define IOD_UNSET          1889        /* Retirer l'IOD de protocole.        */
#define EVT_PRGON          1890        /* Demarrage du dechiffrement         */
#define EVT_PRGUPD         1891        /* La PMT du programme a change       */
#define EVT_PRGOFF         1892        /* Arret du dechiffrement d'un prog.  */
#define C_UPDATE           1893        /* Condition de mise a jour           */
#define C_CAPOS            1894        /* Condition positive de dechiffrage  */
#define C_CANEG            1895        /* Condition negative de dechiffrage  */
#define EVT_PRGADD         1896        /* Demarrage d'un second dechiffrement*/
#define C_HSNEG            1897        /* Host shunning active               */
#define C_HSPOS            1898        /* Host shunning active               */
#define CICA_TO            1899        /* Temporisateur                      */
#define EVT_SDTUPD         1900        /* Chgt SDT                           */
#define CICA_TO2           1901        /* Temporisateur                      */
#define C_CIPLUS           1902        /* Cas Ci + avec Host shunning        */
#define C_SDT_CLR          1903        /* SDT deja presente (cas clear)      */
#define C_SDT_SCR          1904        /* SDT deja presente (cas scramble)   */
#define C_CLEAR            1905        /* Programme en clair                 */
#define C_SCRAMBLED        1906        /* Programme scramble                 */
#define HS_STEP            1907        /* Host shunning                      */
#define HS_TPCHG           1908        /* Changement de TP, SDT a recuperer  */
#define C_RESTART          1909        /* Traitement de restart, cas CI+     */


/* Automate Teletexte .......................................................*/

#define AUT_TTXT             28        /* Teletexte                          */
                                       /*                                    */
#define TTXT_SELECT        1920        /* Selection d'une page pour affichage*/


/* Automate telechargement DSMCC ............................................*/

#define AUT_DSM_FILE         29        /* "$vmos/file/dsmcc.c"               */


/* Automate chargement de librairie dynamique ...............................*/

#define AUT_DL               30        /* "$vmos/divers/elf_dl.c"            */
                                       /*                                    */
#define DL_READ_SYS        1984        /* Debut lecture zone systeme NAND    */
#define DL_READ_LIB        1985        /* Commande de chargement d'une lib.  */
#define DL_FREE_LIB        1986        /* Commande de dechargement d'une lib.*/
#define DL_INIT_DONE       1987        /* Evt de fin d'init systeme.         */
#define DL_TO_INIT         1988        /* Temporisations de initialisations. */
#define DL_TO_FINI         1989        /* Temporisations de terminaisons.    */
#define DL_TO_MD5          1990        /* Temporisation de verification MD5. */
#define DL_TO_BSS          1991        /* Temporisation d'installation BSS.  */
#define DL_TO_RELOC        1992        /* Temporisation de relocation.       */
#define DL_C_READY         1993        /* Cnd: fin d'etape.                  */
#define DL_C_DATA          1994        /* Cnd: fichier de donnees disponible.*/
#define DL_C_ERROR         1995        /* Cnd: erreur de lecture.            */
#define DL_C_ABORT         1996        /* Cnd: arret du chargement.          */
#define DL_C_WAIT          1997        /* Cnd: attendre avant de continuer.  */
#define DL_C_DONE          1998        /* Cnd: fin d'execution de la commande*/
#define DL_C_MD5           1999        /* Cnd: debut de verification MD5.    */
#define DL_C_BSS           2000        /* Cnd: debut de l'installation du BSS*/
#define DL_C_RELOC         2001        /* Cnd: debuter les relocations.      */
#define DL_C_INIT          2002        /* Cnd: debuter les initialisations.  */
#define DL_C_FREED         2003        /* Cnd: fin de liberation d'une lib.  */


/* Automate du service OAD ..................................................*/

#define AUT_SRV_OAD          31        /* "$vmos/telecom/srv_oad.c"          */
                                       /*                                    */
#define OAD_START          2016        /* Debut de recherche OAD.            */
#define OAD_STOP           2017        /* Arret forcee de recherche OAD.     */
#define OAD_TO             2018        /* Timeout de telechargement OAD.     */
#define C_OAD_SBOTH        2019        /* Cnd: charger PAT + (NIT ou BAT).   */
#define C_OAD_SPAT         2020        /* Cnd: charger PAT.                  */
#define C_OAD_SNIT         2021        /* Cnd: charger NIT.                  */
#define C_OAD_SBAT         2022        /* Cnd: charger BAT.                  */
#define C_OAD_SPMT         2023        /* Cnd: charger PMT.                  */
#define C_OAD_SUNT         2024        /* Cnd: charger UNT.                  */
#define C_OAD_SDSI         2025        /* Cnd: charger DSI.                  */
#define C_OAD_SDII         2026        /* Cnd: charger DII.                  */
#define C_OAD_SSC0         2027        /* Cnd: charger Section 0.            */
#define C_OAD_SB0          2028        /* Cnd: charger Bloc 0 du volume.     */
#define C_OAD_WBLK         2029        /* Cnd: charger autres blocs du vol.  */
#define C_OAD_WWRT         2030        /* Cnd: attendre fin d'ecriture.      */
#define C_OAD_FOUND_I      2031        /* Cnd: on a trouve, IDLE.            */
#define C_OAD_FOUND_S      2032        /* Cnd: on a trouve, STOP.            */
#define C_OAD_FAILED_S     2033        /* Cnd: echec/erreur, STOP.           */
#define C_OAD_FAILED_I     2034        /* Cnd: echec/erreur, IDLE.           */
#define C_OAD_DONE         2035        /* Cnd: telechargement du vol termine.*/
#define C_OAD_CONTINUE     2036        /* Cnd: rester dans l'etat courant.   */
#define C_OAD_GIVEN        2037        /* Cnd: donnees transmises par l'appli*/


/* Automate driver pour SecureMedia : AUT_SM_DRV ............................*/

#define AUT_SM_DRV           32        /* "$vmos/acces/sm_drv.c"             */
                                       /*                                    */
#define SM_NVM_WRT         2048        /* Requete d'ecriture en NVM.         */
#define SM_FLT_START       2049        /* Evt: Requete de demarrage filtre.  */
#define SM_FLT_STOP        2050        /* Evt: Requete d'arret d'un filtre.  */
#define SM_FLT_NONE        2051        /* Cnd: Echec d'allocation de filtre. */
#define SM_FLT_FREE        2052        /* Cnd: Liberer le filtre.            */
#define SM_FLT_ALLOC       2053        /* Cnd: Reallouer le filtre.          */
#define SM_FLT_CFG         2054        /* Cnd: Reconfigurer le filtre.       */
#define SM_KEY_SET         2055        /* Evt: Ecrire cles de dechiffrement. */
#define SM_KEY_DEL         2056        /* Evt: Supprimer cles de dechiffremnt*/
#define SM_GET_UID         2057        /* Evt: Requete lecture Unique Id.    */
#define SM_GET_RND         2058        /* Evt: Requete nombre aleatoire.     */
#define SM_GET_MAC         2059        /* Evt: Requete lecture adresse MAC.  */
#define SM_HTTP_GET        2060        /* Evt: Requete HTTP Get.             */
#define SM_HTTP_TO         2061        /* Evt: Fin de temporisation HTTP.    */
#define SM_HTTP_OK         2062        /* Cnd: Succes de requete HTTP.       */
#define SM_HTTP_KO         2063        /* Cnd: Echec  de requete HTTP.       */
#define SM_HTTP_KO2        2064        /* Cnd: Echec  de requete HTTP.       */


/* Nombre max d'automates ...................................................*/

/* ATTENTION Mettre la meme valeur dans NAUTMAX des fichiers *.sys.          */

#define AUTLAST              35        /* Dernier numero d'automate          */


#ifdef _DRO_                           /* Old API driver interface.          */

#define DVBSTL_START       1440        /* Evenement de relance.              */

/*****************************************************************************
 * Numeros des automates du VMIO                                             *
 * -----------------------------                                             *
 *                                                                           *
 * Ces numeros d'automates sont compris entre 128 et 255                     *
 *                                                                           *
 * Pour chaque numero d'automate, on trouve a la suite les codes de ses      *
 * evenements "prives". Le premier de ces codes est toujours egal a          *
 * 1024 + 32 * numero de l'automate. De ce fait, on dispose de 32 codes      *
 * pour chacun des automates                                                 *
 *****************************************************************************/

#define AUTS_FIRST          128        /* Numero premier automate simplifie  */


/* Automate pour devices FRONT-END sat/cab/ter ..............................*/

#define AUT_FRE             128        /* driver/mpeg/drv_fre.c              */
                                       /*                                    */
#define REQ_LNB            5120        /* Requete modification params du LNB */


/* Automates pour device DEMUX ..............................................*/

                                       /* vmio/drvcar/drv_dmx.c              */
#define AUT_DMX             129        /* Automate devices demux.            */
#define AUT_FLT             130        /* Automate filtres demux.            */

/* Note: les evenements qui suivent sont communs a AUT_DMX et AUT_FLT        */

/* Note: evenements propres a AUT_FLT, on va depasser la limite de 32 evts,  */
/*       aussi on utilise des codes reserves a AUT_DMX pour AUT_FLT, etc...  */

#define IT_SEC             5152        /* IT DMA arrivee d'une section       */
#define IT_PKT             5153        /* IT DMA arrivees de donnees paquet  */
#define IT_PES             5154        /* IT DMA arrivees de donnees ES+hdr  */
#define IT_ES              5155        /* IT DMA arrivees de donnees ES      */
#define IT_TRP             5156        /* IT DMA arrivees de donnees PES     */
#define IT_SC              5157        /* IT DMA arrivees start-codes ES     */
#define IT_PES2            5158        /* IT DMA arrivees de donnees PES     */
#define IT_PCR             5159        /* IT arrivee de donnees PCR.         */
#define IT_TRPSEC          5160        /* IT DMA arrivees d'une section TRP. */
#define IT_EIT             5161        /* IT DMA arrivees d'une section EIT. */
#define DMX_IT_INJ         5162        /* IT fin d'injection de donnees      */
#define DMX_IT_INJTO       5163        /* IT arme tempo pour DMX_IT_INJ      */
                                       /*                                    */
#define REQ_FALLOC         5164        /* Dem allocation de cette voie log.  */
#define REQ_FFREE          5165        /* Dem liberation de la VL filtre     */
#define REQ_FSTOP          5166        /* Dem arret du filtre                */
#define REQ_FRUN           5167        /* Dem mise en marche du filtre       */
#define FLT_FCONT          5168        /* Relance automatique d'un filtre.   */
#define TO_DMX             5169        /* Echeance TO de non reception       */
#define C_FSTOP            5170        /* Condition d'arret de filtre.       */
#define C_FFREE            5171        /* Condition de liberation de filtre. */
#define C_FNEXT            5172        /* Condition de relance de filtre.    */
#define C_FTO              5173        /* Condition de timer echu.           */
                                       /*                                    */
#define C_VIDEODEC         5174        /* MODE=VIDEODEC                      */
#define C_AUDIODEC         5175        /* MODE=AUDIODEC                      */
#define C_PACKET           5176        /* MODE=PACKET                        */
#define C_SECTION          5177        /* MODE=SECTION                       */
#define C_SECTION_C        5178        /* MODE=SECTION_CHANGE                */
#define C_TABLE            5179        /* MODE=TABLE                         */
#define C_TABLE_C          5180        /* MODE=TABLE_CHANGE                  */
#define C_MASK             5181        /* MODE=MASK                          */
#define C_MASK_ALL         5182        /* MODE=MASK_ALL                      */
#define C_MASK_T           5183        /* MODE=MASK_TOGGLE                   */
#define C_VBI              5184        /* MODE=VBI                           */
#define C_TTX              5185        /* MODE=TTX                           */
#define C_STL              5186        /* MODE=STL                           */
#define C_TABLES           5187        /* MODE=TABLES (suppression en cours) */
#define C_EITS             5188        /* MODE=EITS                          */
#define C_ALA_ONESH        5189        /* MODE=ALA_ONESHOT                   */
#define C_ALA_TOGGL        5190        /* MODE=ALA_TOGGLE                    */
#define C_ALA_CONT         5191        /* MODE=ALA_CONTINUOUS                */
#define C_PVR_VID          5192        /* MODE=PVR_VID                       */
#define C_PVID_HW          5193        /* MODE=PVR_VID, parsing hardware     */
#define C_PVID_SW          5194        /* MODE=PVR_VID, parsing software     */
#define C_PVR_AUD          5195        /* MODE=PVR_AUD                       */
#define C_PVR_VBI          5196        /* MODE=PVR_VBI                       */
#define C_PVR_STL          5197        /* MODE=PVR_STL                       */
#define C_PVR_SEC          5198        /* MODE=PVR_SECTION                   */
#define C_PVR_PSM          5199        /* MODE=PVR_PSM                       */
#define C_PVR_EITPF        5200        /* MODE=PVR_EITPF                     */
#define C_FWAIT            5201        /* Condition filtre attend des donnees*/
#define C_FEND             5202        /* Condition fin de filtrage.         */
#define C_DEC_VBI          5203        /* MODE=DEC_VBI                       */
#define C_DEC_TTX          5204        /* MODE=DEC_TTX                       */
#define C_TRP              5205        /* MODE=TRP                           */
#define C_PCR              5206        /* MODE=PCR                           */
#define C_PVR_PCR          5207        /* MODE=PVR_PCR                       */
#define C_CANCEL           5208        /* Annuler la transition              */
#define C_SGT              5209        /* MODE=SGT                           */
#define C_SSF              5210        /* MODE=SSF                           */
#define C_TABLE_REF        5211        /* MODE=TABLE_REF                     */
#define C_HLS              5212        /* MODE=HLS                           */
#define C_HLSCLR           5213        /* MODE=HLS, non chiffre.             */
#define C_HLSWPIP          5214        /* MODE=HLS, attendre demarrage pipe. */
                                       /*                                    */
#define AUT_LDMX            131        /* Automate demux couche basse.       */


/* Automate pour device FAN .................................................*/
 
#define AUT_FAN             132        /* vmio/drvcar/drv_fan.c              */


/* Automate pour device decodeur audio MPEG/AC3 .............................*/

#define AUT_AUD             133        /* driver/stb/drv_aud.c               */
#define IT_STARTFRM        5280        /* Frame detectee                     */


/* Automate pour device decodeur video MPEG .................................*/

#define AUT_VID             134        /* driver/stb/drv_vid.c               */
#define IT_DATA            5312        /* Indication nouvelles donnees ES    */
#define IT_STARTCODE       5313        /* Start-code detecte                 */


/* Automate pour device DENC (generation signal video analogique) ...........*/

#define AUT_DEN             135        /* driver/stb/drv_den.c               */
#define TO_DEN    (1024+135*32)        /*                                    */
#define C_HDMDEC           5345        /* Cond pour dechiffrement hdcp_data  */


/* Automate pour device modulateur RF .......................................*/

#define AUT_RFM             136        /* driver/stb/drv_rfm.c               */


/* Automate pour device de commutation des signaux video/audio ..............*/

#define AUT_SWI             137        /* driver/stb/drv_swi.c               */


/* Automate pour devices LEDS ...............................................*/

#define AUT_LED             138        /* driver/genio/drv_led.c             */


/* Automate pour devices afficheurs a segments (DISPLAY) ....................*/

#define AUT_DIS             139        /* driver/genio/drv_dis.c             */


/* Automate pour device POWER ...............................................*/

#define AUT_POW             140        /* driver/genio/drv_pow.c             */


/* Automate protocole I2C ...................................................*/

#define AUT_I2C             141        /* driver/genio/drv_i2c.c             */


/* Automate protocoles infra-rouge (RCU) ....................................*/

#define AUT_RCU             142        /* driver/serial/drv_rcu.c            */
                                       /*                                    */
#define CR_S               5568        /* Cond Raw symbols capture           */
#define CT_S               5569        /* Cond Raw symbols capture           */
#define CR_T               5570        /* Cond telecommande a leader/tail    */
#define CT_T               5571        /* Cond telecommande a leader/tail    */
#define CR_R               5572        /* Cond telecommande a repetition mess*/
#define CT_R               5573        /* Cond telecommande a repetition mess*/
#define CR_6               5574        /* Cond telecommande RC6 mode 0       */
#define CT_6               5575        /* Cond telecommande RC6 mode 0       */
#define CR_5               5576        /* Cond telecommande RC5              */
#define CT_5               5577        /* Cond telecommande RC5              */
#define CR_X               5578        /* Cond protocole XMP                 */
#define CT_X               5579        /* Cond protocole XMP                 */
#define CR_M               5580        /* Cond protocole RCMM                */
#define CT_M               5581        /* Cond protocole RCMM                */
#define C_EVT              5582        /* Cond evt a remonter au VMOS        */
#define C_NOEVT            5583        /* Cond pas d'evt a remonter au VMOS  */
#define C_RCU              5584        /* Cond message RCU                   */
#define C_KBD              5585        /* Cond message Clavier               */
#define C_MSE              5586        /* Cond message Souris                */
#define C_PFIN             5587        /* Cond prochain symbole est STOP     */


/* Automate protocoles ISO 7816 (Cartes a puces) ............................*/

#define AUT_SMC             143        /* driver/genio/drv_smc.c             */
                                       /*                                    */
#define C_OK               5600        /* Cond Pas d'erreur, tout va bien    */
#define C_ERRRCV           5601        /* Cond Erreur IT_RX                  */
#define C_ERRSND           5602        /* Cond Erreur IT_TX                  */
#define C_TOF              5603        /* Cond Erreur TOF sur evt IT_RX      */
                                       /*                                    */
#define C_ENDATRI          5604        /* Cond Plus de caracteres d'interface*/
#define C_ENDATRH          5605        /* Cond Plus de caracteres historiques*/
#define C_ENDATR           5606        /* Cond Fin de l'ATR                  */
#define C_ERRATR           5607        /* Cond ATR incomprehensible          */
#define C_PTS              5608        /* Cond Carte en mode negociable      */
#define C_T0               5609        /* Cond Carte en mode T=0             */
#define C_T1               5610        /* Cond Carte en mode T=1             */
                                       /*                                    */
#define C_SND              5611        /* Cond commande = data sortant       */
#define C_RCV              5612        /* Cond commande = data entrant       */
#define C_ACK1             5613        /* Cond ACK pour recevoir 1 octet     */
#define C_ACKN             5614        /* Cond ACK pour recevoir N octet     */
#define C_SW1              5615        /* Cond Reception de SW1              */
#define C_ENDSND           5616        /* Cond Recu ACK, mais rien a envoyer */
                                       /*                                    */
#define C_STILL            5617        /* Cond Rester dans etat courant.     */
#define C_RESET            5618        /* Cond Debuter sequence de RESET     */
#define C_NOBUF            5619        /* Cond Pas de buffer de reception    */
#define C_NEXTREQ          5620        /* Cond Passer a la requete suivante  */
#define C_GETVAL           5621        /* Cond requete REQ_GETVAL            */
#define C_SETVAL           5622        /* Cond requete REQ_SETVAL            */


/* Codes d'erreurs pour evt IT_RX (champ evt.longueur).......................*/
 
#define ERR_PAR               1        /* Erreur de parite de cara recu      */
#define ERR_FRA               2        /* Pas de stop bit, ou pas correct    */
#define ERR_OVR               3        /* Overrun, perte de caractere recu   */
#define ERR_TOF               4        /* Echeance du TOF                    */
#define ERR_TOI               5        /* Echeance du TOI                    */
#define ERR_ECH               6        /* Echo recu <> cara emis             */
#define ERR_AUT               7        /* Pas recu l'evt attendu             */
#define ERR_SRV               8        /* Le buffer de service est plein.    */
 
 
/* Codes d'erreurs pour evt IT_TX (champ evt.longueur).......................*/
 
#define ERR_NKD               9        /* Caractere emis a ete NACKE         */
#define ERR_SPU              10        /* Erreur sur masque d'IT de l'UART.  */


/* Automate service systeme de fichier FAT ..................................*/

#define AUT_FAT             144        /* src/file/                          */
#define TO_FGET            5632        /* Tempo de relance pipe FAT          */


/* Automate service STR .....................................................*/

#define AUT_STR             145        /* vmio/drvcar/srv_str.c              */
#define PVR_PKT            5664        /* Nouvelles donnees PES issues du dmx*/
#define DEC_PKT            5665        /* Donnees demux pour les decodeurs   */
#define TO_STR1            5666        /* Echeance time-out recorder         */
#define TO_STR2            5667        /* Echeance time-out player TSB       */
#define TO_STR3            5668        /* Echeance time-out player permanent */
#define SYNC_TSB           5669        /* Synchronisation ecr/lec du TSB     */
#define C_NXTJOB           5670        /* Condition prochain job             */
#define RESP_CMD           5671        /* Fin phase critique d'un elt        */
#define FLOW_CTR           5672        /* Controle de flot decodeurs source  */
#define C_CLOSE            5673        /* Condition fermeture                */
#define PVR_TRP            5674        /* Nouvelles donnees TRP issues du dmx*/
#define PVR_SEG            5675        /* Nouveau descripteur de segment dmx */


/* Automate gestion EEPROM ..................................................*/

#define AUT_EEP             146        /* driver/genio/drv_eep.c             */


/* Automate de decodage VIDEO ...............................................*/

#define AUT_VDEC            147        /* vmio/drvcar/drv_vid.c              */


/* Automate driver DISPLAY de bas niveau ....................................*/

#define AUT_DSP             148        /*                                    */


/* Automate driver generique de disque ......................................*/

#define AUT_DSK             149        /*                                    */


/* Automate FLASH ...........................................................*/

#define AUT_FLASH           150        /*                                    */
                                       /*                                    */
#define FLASH_WRITE_END    5824        /*                                    */
#define FLASH_ERASE_END    5825        /*                                    */


/* Automate bas niveau FLASH ................................................*/

#define AUT_LOWFLASH        151        /*                                    */
                                       /*                                    */
#define FLASH_PAUSE        5856        /*                                    */


/* Automates pour la FLASH/EEPROM .......................................... */

#define AUT_SEQUENCE        152        /* Nm Sequence Manager  automaton     */
                                       /* driver/flash/eeprom.c              */
#define LIST_ERROR         5888        /* Error in area list                 */
#define LIST_EMPTY         5889        /* All area updated in the request    */
#define RECLAIM            5890        /* Entry event : start reclaim        */
#define BACKUP_AREA        5891        /* Start backup of a part of an area  */
#define WEAR_LEVEL         5892        /* Wear levelling necessary           */
#define BLK_TRANSFERRED    5893        /* Reclaim completion event           */
#define BLK_TRANSFER_ERROR 5894        /* Reclaim error      event           */
                                       /*                                    */
#define EEP_BACKUP_WRITE   5895        /* Pseudo request event               */
                                       /*                                    */
#define AUT_SINGLE          153        /* Nm Single-instance   automaton     */
                                       /* driver/flash/single.c              */
#define FLASH_FULL         5920        /* Flash device is full               */
#define REPLACE_UNIT       5921        /* Replace previous valid unit        */
                                       /*                                    */
#define AUT_MULTIPLE        154        /* Nm Multiple-instance automaton     */
                                       /* driver/flash/multip.c              */
#define REPLACE_INSTANCE   5952        /* Replace previous instance          */
#define INVALID_UNIT       5953        /* Invalid previous valid unit        */
                                       /*                                    */
#define AUT_RECLAIM         155        /* Nm Reclaim           automaton     */
                                       /* driver/flash/reclaim.c             */
#define RECOVER_COPY       5984        /* Entry event : restart from copy    */
#define RECOVER_ERASING    5985        /* Entry event : restart from erasing */
#define RECOVER_UPDATING   5986        /* Entry event : restart from updating*/
#define NO_UNIT_FOUND      5987        /* No unit found                      */
#define RECLAIM_ERROR      5988        /* Reclaim recovery error      event  */
#define TRANSFER_INSTANCE  5989        /* Transfer an instance               */
                                       /*                                    */
#define AUT_PLR             156        /* Nm PLR               automaton     */
                                       /* driver/flash/plr.c                 */
#define BEGIN_PLR_CHECK    6016        /* Start PLR                          */
#define PLR_CHECK          6017        /* Start/Restart PLR                  */
#define PLR_RECLAIM        6018        /* Reclaim Recovery necessary         */
#define PLR_NULL           6019        /* Incoherent unit, set to 'NULL'     */
#define PLR_INVALIDATING   6020        /* Interrupted update, recover        */
#define PLR_VALID          6021        /* Interrupted update, recover        */
#define PLR_INVALID        6022        /* Incoherent unit, set to 'INVALID'  */
#define PLR_INST           6023        /* Incoherent instance, set to 'INV.' */
#define PLR_CORRECT_CELL_LEVEL 6024    /* Incoherent state cell value found. */
#define RECLAIM_DONE       6025        /* Reclaim recovery completion event  */
                                       /*                                    */
#define EEP_PLR_CHECK      6026        /* Pseudo request event               */
                                       /*                                    */
#define AUT_RECREC          157        /* Nm Reclaim Recovery  automaton     */
                                       /* driver/flash/reclaim.c             */
#define RECLAIM_RECOVER    6048        /* Start.                             */
#define RECLAIM_COPY       6049        /* Recover reclaim from COPY          */
#define RECLAIM_RECLAIM    6050        /* Recover a full reclaim             */
#define RECLAIM_BACKUP     6051        /* Backup spare block erase counter   */
#define RECLAIM_NO_BACKUP  6052        /* Backup impossible, do without      */


/* Automate pour les systemes de fichier en FLASH .......................... */

#define AUT_FDF             158        /* vmio/flash/flashdf.c               */
                                       /*                                    */
#define FDF_PLR            6080        /* Lancement du PLR.                  */
#define CND_PLR_RECOVER    6081        /* Recuperation pour PLR.             */
#define CND_FDF_PLR        6082        /* Relance du PLR                     */
#define FDF_CLOSE          6083        /* Fermeture du disque.               */
#define FDF_CRE_FILE       6084        /* Ordre de creation  d'un fichier.   */
#define FDF_DEL_FILE       6085        /* Ordre d'effacement d'un fichier.   */
#define FDF_OPEN_WRT       6086        /* Ordre d'ouverture  d'un fichier.   */
#define FDF_OPEN_RD        6087        /* Ordre d'ouverture  d'un fichier.   */
#define FDF_CLOSE_FILE     6088        /* Ordre de fermeture d'un fichier.   */
#define FDF_NOTHING        6089        /* Passe a l'etape suivante.          */
#define FDF_TRANSFER       6090        /* Ordre de transferer les fichiers.  */
#define FDF_UMOUNT         6091        /* Demontage d'un disque              */
                                       /*                                    */
#define CND_FLASH_BSY      6092        /* Condition device Flash pas pret    */
#define FDF_REQ_CREFILE    6093        /* Evenement pseudo-requete crefile   */
#define FDF_REQ_DELFILE    6094        /* Evenement pseudo-requete delfile   */
#define FDF_REQ_FLIST      6095        /* Evenement pseudo-requete flist     */
#define FDF_REQ_FINFO      6096        /* Evenement pseudo-requete finfo     */
#define FDF_REQ_FOPEN      6097        /* Evenement pseudo-requete fopen     */
#define FDF_REQ_FCLOSE     6098        /* Evenement pseudo-requete fclose    */
#define FDF_REQ_FGET       6099        /* Evenement pseudo-requete fget      */
#define FDF_REQ_FPUT       6100        /* Evenement pseudo-requete fput      */


/* Automates de chargement via une carte a puce .............................*/

#define AUT_SMCLD           159        /*                                    */
#define C_LDERR            6112        /*                                    */
#define C_LDEND            6113        /*                                    */
#define ERR_LD                1        /*                                    */
#define ERR_CD                2        /*                                    */


/* Automate CLOCK ...........................................................*/

#define AUT_CLK             160        /* $vmio/drvsys/drv_clk.c             */
                                       /*                                    */
#define REQ_CLOCK          6144        /* Demande de valeur d'horloge        */
#define RESP_CLOCK         6145        /* Reponse de valeur d'horloge        */
#define SET_CLOCK          6146        /* Modification d'offset d'horloge    */


/* Automate ASI .............................................................*/

#define AUT_ASI             161        /* $vmio/drvcar/drv_asi.c             */
                                       /*                                    */
#define C_OUT              6176        /* Ouverture en emission.             */
#define C_IN               6177        /* Ouverture en reception.            */
#define IT_CFG             6178        /* Changement d'etat de l'interface.  */
#define ASI_PSTART         6179        /* Pipe pret a recevoir/transmettre.  */
#define ASI_PSTOP          6180        /* Pipe a l'arret.                    */
#define C_ASI_PSTOP        6181        /* Condition pipe a l'arret.          */
#define C_DEV_STOP         6182        /* Condition device pas pret.         */


/* Automate ASY .............................................................*/

#define AUT_ASY             162        /*                                    */
                                       /*                                    */
#define REQ_IO             6208        /*                                    */
#define REQ_GETSYS         6209        /*                                    */
#define RESP_GETSYS        6210        /*                                    */
#define IT_SIG             6211        /*                                    */
#define TO_FILE0           6212        /*                                    */
#define TO_FILE1           6213        /*                                    */
#define TO_FILE2           6214        /*                                    */


/* Automate MPLEX ...........................................................*/

#define AUT_MPLEX           163        /* $vmio/drvcar/srv_mplex.c           */
                                       /*                                    */
#define MPLEX_OUTPUT       6240        /* Pipe de sortie disponible.         */
#define C_DUMP             6241        /* Condition extraction de table.     */
#define C_ADDTABLE         6242        /* Condition insertion de table.      */


/* Automate serveur DHCP ....................................................*/

#define AUT_DHCP            164        /* $vmio/srv/srv_dhcp.c               */
                                       /*                                    */
#define TO_CHECK           6272        /* Tempo. de verif. d'expiration      */


/* Automate transcodage Dolby E-AC-3 vers AC-3 ..............................*/

#define AUT_EAC3            165        /* $vmio/drvcar/aud_eac3.c            */
                                       /*                                    */
#define TO_RUN             6304        /* Evenement de relance.              */


/* Automate FACTORY TEST ....................................................*/

#define AUT_FCT             166        /* $vmio/drvcar/drv_facttest.c        */


/* Automate de recherche de nom de domaine ..................................*/

#define AUT_DNS             167        /* vmio/drvcar/srv_dns.c              */


/* Automate USB .............................................................*/

#define AUT_USB              168       /* "$vmio/drvsys/drv_usb.c"           */
                                       /*                                    */
#define TO_USB              6368       /* Temporisateur                      */
#define IT_CSC              6369       /* Changement de status d'un port     */
#define C_CSC               6370       /* Changement de status d'un port     */
#define C_ATTACH            6371       /* Notification d'attachement         */
#define C_DETACH            6372       /* Notification de detachement        */
#define C_HSTOP             6373       /* Hub upstream arrete                */
#define C_POWEROFF          6374       /* Port mis hors tension              */
#define C_HUB               6375       /* Condition sur Hub                  */
#define C_PORT              6376       /* Condition sur Port                 */
#define C_LOWSPEED          6377       /* Device attache n'est pas High Speed*/
#define C_DISABLE           6378       /* Port place dans l'etat disabled    */
#define REQ_ADDR            6379       /* Requete d'adressage peripherique   */
#define RESP_ADDR           6380       /* Reponse a l'adressage du periph.   */
#define USB_SREQ            6381       /* Hub libre, requete vers Hub OK     */
#define USB_BUSY            6382       /* Hub occupe, echec requete          */
#define USB_PPOK            6383       /* Mise sous tension Port terminee    */
#define USB_HRST            6384       /* Reset Port termine                 */
#define IT_USB              6385       /* Message transfert interruption Hub */
#define USB_PREQ            6386       /* Requete Port vers Hub              */
#define USB_PASSIGN         6387       /* VL assignee a un port d'un hub     */
#define USB_PSTATUS         6388       /* envoi status du port par le hub    */
#define USB_PRSTEND         6389       /* envoi Reset Port Termine           */
#define USB_REQOK           6390       /* Requete envoyee (Hub vers Port)    */
     

/* Automate PCMCIA ..........................................................*/

#define AUT_PCM              169       /* "$vmio/drvcar/drv_pcm.c"           */
                                       /*                                    */
#define DEVREQ_OPEN         6432       /* Requete d'ouverture  controlleur   */
#define DEVREQ_CLOSE        6433       /* Requete de fermeture controlleur   */
#define DEVRESP_OPEN        6434       /* Reponse d'ouverture  controlleur   */
#define DEVRESP_CLOSE       6435       /* Reponse de fermeture controlleur   */
#define IT_INSERT           6436       /* Insertion d'un module dans un slot */
#define IT_EJECT            6437       /* Ejection  d'un module d'un slot    */
#define PCM_TO              6438       /* Temporisateur pour le haut niveau  */
#define PCM_LOWTO           6439       /* Temporisateur pour le bas niveau   */
#define PCM_BUSGOT          6440       /* Obtention du control du bus        */
#define C_BLK               6441       /* Condition, slot de type bloc       */
#define C_CAR               6442       /* Condition, slot de type caractere  */
#define C_UNK               6443       /* Condition, slot de type "inconnu"  */
#define DEV_REPORT          6444       /* Notification : le bit IIR est a 1  */
#define IT_INIT             6445       /* Demande d'initialisation specifique*/
#define C_INSERT            6446       /* Condition, module insere           */
#define C_EJECT             6447       /* Condition, module extrait          */
#define C_INIT              6448       /* Condition, init a faire            */


/* Automate DVB-CI ..........................................................*/

#define AUT_CI       (UINT)  170       /* "$vmio/drvpro/pro_ci.c"            */
                                       /*                                    */
#define CI_TO               6464       /* Temporisateur                      */
#define CI_RUNRSA           6465       /* Reprise du calcul RSA              */
#define IND_OPEN            6466       /* Indication d'ouverture protocole   */
#define IND_HALT            6467       /* Indication d'arret     protocole   */
#define C_CALCRSA           6468       /* Condition calul de RSA             */
#define CI_CHKCERT          6469       /* Condition verif de Certificat      */
#define CI_NVMWR            6470       /* Requete d'ecriture en NVM          */
#define CI_CHKDEC           6471       /* Condition de dechiffrement de certs*/
#define CI_TOLIC            6472       /* Timeout pour valider une licence   */
#define C_IHMOPEN           6473       /* Condition d'attente accord UI      */
#define CI_TOURI            6474       /* Timeout de reception d'URI valide  */


/* Automate TELNET (unused) .................................................*/

#define AUT_TELNET           171       /* $vmiodev/srv/srv_telnet.c (unused) */


/* Automate USB OHCI ........................................................*/

#define AUT_USBOHCI          172       /* $vmio/drvsys/drv_usbohci.c         */
                                       /*                                    */
#define IT_DONE             6529       /* Transfert descriptor traite        */
#define IT_RESET            6530       /* Reset peripherique termine         */
                                       /*                                    */
#define TO_RESET            6535       /* Temporisateur reset controleur     */
#define TO_CSC              6536       /* Temporisateur connexion stable     */
#define TO_POWER            6537       /* Temporisateur alimentation stable  */
#define TO_AD               6538       /* Temporisateur adresse acceptee     */
#define TO_HID              6539       /* Temporisateur human-interface dev  */
                                       /*                                    */
#define USB_START           6540       /* Demarrage d'un port                */
#define USB_CONN            6541       /* Connexion/deconnexion d'un periph  */


/* Automate interface clavier/telecommande ..................................*/

#define AUT_KBDITF           173       /*                                    */


/* Automate interface USB ...................................................*/

#define AUT_USBITF           174       /*                                    */


/* Automate interface MBX ...................................................*/

#define AUT_MBX              175       /*                                    */


/* Automate ETHERNET ........................................................*/

#define AUT_ETH              176       /* "$vmio/drvcar/drv_eth.c"           */
                                       /*                                    */
#define REQ_IFBIND          6688       /* Empilement protocole de niveau sup.*/
#define RESP_IFBIND         6689       /* Reponse au REQ_IFBIND              */
#define REQ_UNBIND          6690       /* Depilement protocole de niveau sup.*/
#define RESP_UNBIND         6691       /* Reponse au RESP_UNBIND             */
#define REQ_IFSTART         6692       /* Demarrage protocole de niveau sup. */
#define RESP_IFSTART        6693       /* Reponse au REQ_IFSTART             */
#define REQ_IFSTOP          6694       /* Arret protocole de niveau sup.     */
#define RESP_IFSTOP         6695       /* Reponse au REQ_IFSTOP              */
#define TO_PHY              6696       /* Time-out polling etat du PHY.      */
#define C_CONFLICT          6697       /* Condition detection adr. utilisee  */
#define REQ_TUNNEL          6698       /* Tunnel a request through ethernet  */
#define TO_DELAY            6699       /* Time-out delayed frame             */


/* Automate LOOPBACK ........................................................*/

#define AUT_LO               177       /* "$vmio/drvcar/drv_lo.c"            */


/* Automate IP ..............................................................*/

#define AUT_IP               178       /* "$vmio/drvpro/pro_ip.c"            */
                                       /*                                    */
#define C_IP                6720       /* Condition ouverture en mode IP     */
#define C_DHCP              6721       /* Condition ouverture en mode DHCP   */
#define C_TCP               6722       /* Condition ouverture en mode TCP    */
#define C_UDP               6723       /* Condition ouverture en mode UDP    */
#define C_RTP               6724       /* Condition ouverture en mode RTP    */
#define C_RAW               6725       /* Condition ouverture en mode RAW    */
#define C_IFDOWN            6726       /* Condition detection interface down */
#define IND_IFDOWN          6727       /* Rapport interface down vers cnx.   */
#define C_REQ_DISCONNECT    6728       /* Deconnection asynchrone            */
#define REQ_DESTROY         6729       /* Dernier evt pour la connexion.     */
#define IT_DOWN             6730       /* Prevenir cnx que interface arretee */
#define TO_DHCP             6731       /* Time-out de non reponse DHCP/lease */
#define TO_RENEW            6732       /* Time-out de renouvellement bail    */
#define TO_REBIND           6733       /* Time-out de reassociation DHCP     */
#define TO_RETRANS          6734       /* Time-out de retransmission.        */
#define TO_ACK              6735       /* Time-out d'acquittement.           */
#define TO_PROBE            6736       /* Time-out de Zero-Window Probing.   */
#define TO_2MSL             6737       /* Time-out fermeture connexion.      */
#define TO_ABORT            6738       /* Time-out reset connexion.          */
#define TO_RTP              6739       /* Time-out lecture d'un paquet RTP.  */
#define TO_RTCP             6740       /* Time-out emission d'un paquet RTCP.*/
#define TO_IGMP             6741       /* Time-out rapport IGMP              */
#define TO_ICMP             6742       /* Time-out rapport ICMP              */
#define TO_QUERY            6743       /* Time-out General Query IGMPv3      */
#define TO_REPORT           6744       /* Time-out reception rapports IGMPv3 */
#define TO_SQUERY           6745       /* Time-out Specific Query IGMPv3     */


/* Automate devices USB .....................................................*/

#define AUT_USBD             179       /* $vmio/drvcar/drv_usbd.c            */


/* Automate DSM-CC ..........................................................*/

#define AUT_DSM              180       /* "$vmio/drvpro/pro_dsm.c"           */
                                       /*                                    */
#define REQ_READSRG         6784       /* Requete de lecture du "SRG"        */
#define IND_DSI             6785       /* Indication reception de DSI        */
#define IND_DII             6786       /* Indication reception de DII        */
#define IND_DDB             6787       /* Indication reception de DDB        */


/* Automate FTP-DATA ........................................................*/

#define AUT_FTP              181       /* "$vmio/drvpro/pro_ftp.c"           */
                                       /*                                    */
#define REQ_RETR            6816       /* Reception commande RETR            */
#define REQ_STOR            6817       /* Reception commande STOR            */


/* Automate ARP .............................................................*/

#define AUT_ARP              182       /* "$vmio/drvcar/drv_eth.c"           */
                                       /*                                    */
#define REQ_RESOLVE         6850       /* Requete de resolution d'adresse    */
#define RESP_RESOLVE        6851       /* Reponse de resolution d'adresse    */
#define C_PROBENUM          6852       /* Condition de fin de probing        */
#define C_ANNOUNCE          6853       /* Condition de reemission d'annonce  */


/* Automate PLAY ............................................................*/

#define AUT_PLAY             183       /* "$vmio/drvcar/srv_play.c"          */
                                       /*                                    */
#define C_OPEN_FILE         6880       /* Requete demarrage "file:"          */
#define C_OPEN_HTTP         6881       /* Requete demarrage "http:"          */
#define C_TOKENS            6882       /* Condition jetons disponibles       */
#define C_LOCAL             6883       /* Cnd demarrage avec serveur local   */
#define C_REMOTE            6884       /* Cnd demarrage avec serveur distant */


/* Automate SEC .............................................................*/

#define AUT_SEC              184       /* "$vmio/drvcar/drv_sec.c"           */
                                       /*                                    */
#define SEC_DMA_LOW         6912       /* Evt callback (TK)DMA du bas niveau */
#define SEC_DMA_SETVAL      6913       /* Evt callback (TK)DMA de REQ_SETVAL */


/* Automate GLUE ............................................................*/

#define AUT_GLUE             185       /* "$vmio/drvvol/drv_glue.c"          */
                                       /*                                    */
#define C_OPENPUSH          6944       /* Requete demarrage en mode "push"   */
#define C_OPENPULL          6945       /* Requete demarrage en mode "pull"   */
#define C_FCLOSE            6946       /* Cnd fermeture du fichier cible     */
#define C_FIN               6947       /* Cnd atteinte fin du flot entrant   */
#define C_FPUT              6948       /* Cnd ecriture du buffer bloc        */
#define C_FPUT_FIN          6949       /* Cnd ecriture du dernier buffer bloc*/
#define C_FPUT_CLOSE        6950       /* Cnd derniere ecriture avant close  */
#define TO_PGSEEK           6951       /* Evt echeance tempo rpt REQ_GSEEK   */
#define TO_PFGET            6952       /* Evt echeance tempo rpt REQ_FGET    */


/* Automate HTTP ............................................................*/

#define AUT_HTTP             186       /* "$vmio/drvcar/srv_http.c"          */
                                       /*                                    */
#define REQ_RUN             6976       /* Evenement de relance du prog EMU32 */
#define REQ_PIPGET          6977       /* Evt depose sur appel a "get"       */
#define REQ_PIPPUT          6978       /* Evt depose sur appel a "put"       */
#define REQ_PIPSEEK         6979       /* Evt depose sur appel a "seek"      */
#define C_CONNECTED         6980       /* Cnd connecte au serveur HTTP       */
#define C_DISCONNECTED      6981       /* Cnd deconnecte du serveur HTTP     */
                                       /*                                    */
#ifdef NSRV_HTTP_C                     /*                                    */
#define REQ_PIPESEEK        6976       /* Le pipe demande un seek            */
#define TO_KEEPALIVE        6977       /* Tempo de fin de keep-alive         */
#define C_STOP              6980       /* Aut. "master" indique fin          */
#define C_STOPERR           6981       /* Aut. "master" indique fin avec err.*/
#define C_NOREAD            6982       /* Erreur lecture url/headers         */
#endif                                 /*                                    */


/* Automate PIPE  ...........................................................*/

#define AUT_PIPE             187       /* "$vmio/drvsys/drv_pipe.c"          */
                                       /*                                    */
#define REQ_POPEN           7008       /*                                    */
#define REQ_PCLOSE          7009       /*                                    */
#define REQ_PSTART          7010       /*                                    */
#define REQ_PSTOP           7011       /*                                    */
#define REQ_PGETVAL         7012       /*                                    */
#define RESP_POPEN          7013       /*                                    */
#define RESP_PCLOSE         7014       /*                                    */
#define RESP_PSTART         7015       /*                                    */
#define RESP_PSTOP          7016       /*                                    */
#define RESP_PGETVAL        7017       /*                                    */


/* Automate CIMAX ...........................................................*/

#define AUT_CIMAX            188       /* $vmio/stb/cimax.c                  */
                                       /*                                    */
#define CIMAX_START         7040       /* Evt de demarrage                   */
#define C_UPLOAD_DONE       7041       /* Cnd upload du firmware termine     */
#define C_CONFIG_DONE       7042       /* Cnd config des registres terminee  */
#define CIMAX_EVT           7043       /* Evt en provenance du module        */
#define CIMAX_READY         7044       /* CIMAX configure par drv_path       */


/* Automate MP3 .............................................................*/

#define AUT_MP3              189       /*                                    */


/* Automate HLS .............................................................*/

#define AUT_HLS              190       /*                                    */


/* Automate PATH ............................................................*/

#define AUT_PTH              191       /* $vmio/drvcar/drv_path.c            */
                                       /*                                    */
#define C_APPLYCMD          7136       /* Cnd reception setval APPLYCMD=SET. */
#define C_POWERON           7137       /* Cnd Mise sous tension d'un groupe. */


/* Automate TLS  ............................................................*/

#define AUT_TLS              192       /* $vmio/drvpro/pro_tls.c             */
                                       /*                                    */
#define TLS_DO_RNG          7168       /* Demarrer/relancer calcul RNG.      */
#define TLS_DO_AES          7169       /* Relance calcul AES sw.             */
#define TLS_DO_RSA          7170       /* Relance calcul RSA sw.             */
#define TLS_DO_MAC          7171       /* Relance calcul HMAC sw.            */
#define TLS_ERR             7172       /* Erreur detectee par handshake.     */
#define TLS_CONN            7173       /* Fin de connexion TLS.              */
#define TLS_DISCO           7174       /* Fin de deconnexion TLS.            */
#define TLS_DMA_END         7175       /* Fin de copie DMA.                  */
#define TLS_C_DONE          7176       /* Cnd : fin d'etape avec succes.     */


/* Automate STL  ............................................................*/

#define AUT_STL              193       /* $vmio/drvcar/srv_stl.c             */


/*****************************************************************************
 * Attention, Nb max d'automates VMIO defini par MAXAUT_S                    *
 * Actuellement (MAXAUT_S = 96) le dernier automate autorise est le __224__  *
 * PJB 22/09/2015 : Depuis aujourd'hui ce dernier automate est defini dans   *
 * vmiodat_xyz.c . Dans le cas vmiodat_stb.c, MAXAUT_S = 96, et le dernier   *
 * automate autorise est le __224__.                                         *
 *****************************************************************************/


#else                                  /* API driver interface.              */

/*****************************************************************************
 * Numeros des automates du VMIO                                             *
 * -----------------------------                                             *
 *                                                                           *
 * Ces numeros d'automates sont compris entre 128 et 255                     *
 *                                                                           *
 * Pour chaque numero d'automate, on trouve a la suite les codes de ses      *
 * evenements "prives". Le premier de ces codes est toujours egal a          *
 * 1024 + 32 * numero de l'automate. De ce fait, on dispose de 32 codes      *
 * pour chacun des automates                                                 *
 *****************************************************************************/

#define FEVT(aut) (1024+32*(aut))      /* Premier code d'evenenement dispo.  */
#define LEVT(aut) (1024+32*(aut)+31)   /* Dernier code d'evenenement dispo.  */

#define AUTS_FIRST         128         /* Numero premier automate simplifie  */

/* Automate de resolution des noms de drivers ...............................*/

#define AUT_RESOLVE        128         /* vmio/drvsys/drv_rslv.c             */

/* Automate interface clavier/telecommande ..................................*/

#define AUT_KBDITF         129         /* vmio/drvcar/drv_kbditf.c           */

/* Automate DAC .............................................................*/

#define AUT_DAC            130         /* vmio/drvcar/drv_dac.c              */

/* Automate ADC .............................................................*/

#define AUT_ADC            131         /* vmio/drvcar/drv_adc.c              */

/* Automate ASY .............................................................*/

#define AUT_ASY              135       /* vmio/drvsys/drv_asy.c              */

#define REQ_IO              5344       /* Requete de relance req_lib.c       */
#define IT_SIG              5345       /* Changement d'etat signal de jnctin */

#define TO_SIG0             5346       /* Tempo file d'ecriture              */
#define TO_SIG1             5347       /* Tempo file de lecture              */
#define TO_SIG2             5348       /* Tempo file autre                   */
#define TO_MSEC0            5349       /* Tempo file d'ecriture              */
#define TO_MSEC1            5350       /* Tempo file de lecture              */
#define TO_MSEC2            5351       /* Tempo file autre                   */

#if REQ_IO != FEVT(AUT_ASY)
  #error "AUT_ASY first event has wrong number !"
#endif

#if TO_MSEC2 > LEVT(AUT_ASY)
  #error "AUT_ASY defines too many events !"
#endif

/* Automate SRF .............................................................*/

#define AUT_SRF            136         /* vmio/drvcar/drv_srf.c              */

/* Automate BLT .............................................................*/

#define AUT_BLT            137         /* vmio/drvcar/drv_blt.c              */

/* Automate SPI .............................................................*/

#define AUT_SPI            138         /* vmio/drvsys/drv_spi.c              */

/* Automate GPIO ............................................................*/

#define AUT_GPIO           139         /* vmio/drvsys/drv_gpio.c             */

/* Automate LED .............................................................*/

#define AUT_LED            140         /* vmio/drvcar/drv_led.c              */

/* Automate protocoles infra-rouge (RCU) ....................................*/

#define AUT_RCU            141         /* vmio/drvsys/drv_rcu.c              */

#define CR_S               5536        /* Cond Raw symbols capture           */
#define CT_S               5537        /* Cond Raw symbols capture           */
#define CR_T               5538        /* Cond telecommande a leader/tail    */
#define CT_T               5539        /* Cond telecommande a leader/tail    */
#define CR_R               5540        /* Cond telecommande a repetition mess*/
#define CT_R               5541        /* Cond telecommande a repetition mess*/
#define CR_6               5542        /* Cond telecommande RC6 mode 0       */
#define CT_6               5543        /* Cond telecommande RC6 mode 0       */
#define CR_5               5544        /* Cond telecommande RC5              */
#define CT_5               5545        /* Cond telecommande RC5              */
#define CR_X               5546        /* Cond protocole XMP                 */
#define CT_X               5547        /* Cond protocole XMP                 */
#define CR_M               5548        /* Cond protocole RCMM                */
#define CT_M               5549        /* Cond protocole RCMM                */
#define C_EVT              5550        /* Cond evt a remonter au VMOS        */
#define C_NOEVT            5551        /* Cond pas d'evt a remonter au VMOS  */
#define C_RCU              5552        /* Cond message RCU                   */
#define C_KBD              5553        /* Cond message Clavier               */
#define C_MSE              5554        /* Cond message Souris                */
#define C_PFIN             5555        /* Cond prochain symbole est STOP     */

/* Automate protocole I2C ...................................................*/

#define AUT_I2C            142         /* driver/genio/drv_i2c.c             */

#if CR_S != FEVT(AUT_RCU)
  #error "AUT_RCU first event has wrong number !"
#endif

#if C_PFIN > LEVT(AUT_RCU)
  #error "AUT_RCU defines too many events !"
#endif

#endif                                 /* End of old/new API interface.      */


/*
    2    Structures and typedefs
    ____________________________
*/


/*
    3    Public variables
    _____________________
*/


/*
    4    Prototypes of public procedures
    ____________________________________
*/


#endif                                 /* End of AUTOMATON_H.                */
