/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     File "include/drv.h"                 */
/*  Constants and definitions for drivers interface.                         */
/*                                                                           */
/*  Author : JYA                        Last modification : 22/10/2016       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations =======================================================


         1  Defines
            1.1 Constantes de definition des types de drivers
            1.2 Constantes du decoupage en bits du champ "longueur" du REQ_OPEN
         2  Structures and typedefs
            2.1 Structure de description d'un tag (ROM)
            2.2 Structure de description d'un driver systeme du VMOS (ROM)
            2.3 Structure de description d'un driver du VMOS (ROM)
            2.4 Structure d'iteration pour manipulation des listes de registres
         3  Public variable
         4  Prototypes of public procedures


*/


#ifndef DRV_H                          /* If this file is not already        */
#define DRV_H                          /* included, include it.              */


/*
    1    Defines
    ____________
*/


/*
    1.1 Constantes de definition des types de drivers
    -------------------------------------------------
*/


/*****************************************************************************
 * Ces constantes sont utilises pour les champs "typdrv" des structures VMOS *
 * "Sys_driver", "Dps_driver" et "Df_driver".                                *
 * Elles sont egalement utilisees pour le champ "typdrv" de la structure VMIO*
 * "Drv_desc"..                                                              *
 *****************************************************************************/


#define DRV_SYS               0        /* Driver systeme                     */
#define DRV_CAR               1        /* Driver caractere                   */
#define DRV_PRO               2        /* Protocole                          */
#define DRV_SER               3        /* Service                            */
#define DRV_BLK               5        /* Driver bloc                        */
#define DRV_VOL               6        /* Driver volume                      */


/*
    1.2 Constantes du decoupage en bits du champ "longueur" du REQ_OPEN
    -------------------------------------------------------------------
*/


#define NO_MSKR        (UCHAR)255      /* Pas de registre de masque.         */


/*
    2    Structures and typedefs
    ____________________________
*/


/*
    2.1 Structure de description d'un tag (ROM)
    -------------------------------------------
*/


/*****************************************************************************
 * Le champ "ptag" de la structure "Dps_driver" pointe un tableau de         *
 * structures "Ptag". Ce tableau contient une structure de type "Ptag" par   *
 * TAG. Chaque structure "Ptag" decrit les proprietes d'un seul tag. Cette   *
 * structure ne contient PAS le nom du tag. La structure "Dps_driver"        *
 * contient un champ nomme "tag", qui pointe un tableau d'adresses de        *
 * chaines, ces chaines sont les noms des tags. De meme, lorsqu'un tag est   *
 * un ENUM, la liste des valeus possibles n'est PAS dans la structure "Ptag",*
 * mais est pointee par le champ "val" de la structure "Dps_driver".         *
 *****************************************************************************/


#ifndef _DRO_

typedef struct                         /* Proprietes d'un tag                */
  BEGIN                                /* ---------------------------------- */
    UCHAR           type             ; /* Type de tag                        */
    UINT            acces            ; /* Accessibilite du tag               */
    USHORT          valr             ; /* Numero du 1er reg. pour le tag.    */
    USHORT          nbr              ; /* Nombre de registres pour le tag    */
    UCHAR           shift            ; /* Shift vers la gauche a appliquer.  */
    UINT            mask             ; /* Masque a appliquer sur valeur recue*/
    UINT            sessid_mod       ; /* Indication de changement de sessid */
  END               Ptag             ; /* ---------------------------------- */

#else

typedef struct                         /* Proprietes d'un tag                */
  BEGIN                                /* ---------------------------------- */
    UCHAR           type             ; /* Type de tag                        */
    UCHAR           acces            ; /* Accessibilite du tag               */
    UCHAR           valr             ; /* Numero du 1er reg. pour le tag.    */
    UCHAR           nbr              ; /* Nombre de registres pour le tag    */
    UCHAR           shift            ; /* Shift vers la gauche a appliquer.  */
    UINT            mask             ; /* Masque a appliquer sur valeur recue*/
  END               Ptag             ; /* ---------------------------------- */

#endif

typedef struct                         /* Pointeurs sur les infos des tags.  */
  BEGIN                                /* ---------------------------------- */
    INT             ntag             ; /* Nombre de tags.                    */
    const UCHAR    *const *tag       ; /* Tableau adresses des noms des tags */
    const UCHAR    *const *val       ; /* Tableau des valeurs des tags ENUM. */
    const Ptag     *ptag             ; /* Tableau des proprietes des tags.   */
  END               Drv_tag          ; /* ---------------------------------- */

typedef struct                         /* Numero de tag -> numero de reg.    */
  BEGIN                                /* ---------------------------------- */
    UINT            reg              ; /* Numero du 1er reg. pour le tag.    */
    UINT            msk              ; /* Numero du reg. de masque de ce tag.*/
  END               Tag2reg          ; /* ---------------------------------- */


/*
    2.2 Structure de description d'un driver systeme du VMOS (ROM)
    --------------------------------------------------------------
*/


/*****************************************************************************
 * Un VMOS possede un tableau nomme "vmos_driver[]", qui lui permet de       *
 * retrouver ses drivers, ses piles de protocoles et services. Le tableau    *
 * "vmos_driver" est un tableau d'adresses de structures de type             *
 * "Sys_driver", "Dps_driver" et "Df_driver". Chaque module C "driver        *
 * systeme" contient une structure "Sys_driver" dont l'adresse sera l'un des *
 * elements de "vmos_driver". L'indice dans "vmos_driver[]" est appele le    *
 * "major number".                                                           *
 *****************************************************************************/


typedef struct  sys_driver             /* Un driver systeme                  */
  BEGIN                                /* ---------------------------------- */
    CHAR            name[STDNAME]    ; /* Nom du driver systeme              */
    CHAR            typdrv           ; /* Vaut toujours 0                    */
    IWORD           (*drv_evt   )()  ; /* Ad procedure xxx_yyy_evt           */
  END               Sys_driver       ; /* ---------------------------------- */


/*
    2.3 Structure de description d'un driver du VMOS (ROM)
    ------------------------------------------------------
*/


/*****************************************************************************
 * Chaque module C de type driver, pile de protocoles ou service contient la *
 * definition d'une structure "Dps_driver", dont l'adresse sera l'un des     *
 * elements de "vmos_driver". L'indice dans "vmos_driver[]" est appele le    *
 * "major number".                                                           *
 *****************************************************************************/

#ifndef _DRO_

typedef struct  dps_driver             /* Un driver/protocole/service        */
  BEGIN                                /* ---------------------------------- */
    CHAR            name[STDNAME]    ; /* Nom du driver/protocole/service    */
    CHAR            typdrv           ; /* 001:dcar 010:proto 011:ser 100:dblk*/

    IWORD       (*drv_evt         )(); /* Ad procedure xxx_yyy_evt           */
    IWORD       (*drv_info        )(); /* Ad procedure xxx_yyy_info          */
    IWORD       (*drv_init        )(); /* Ad procedure xxx_yyy_init          */
    IWORD       (*drv_end         )(); /* Ad procedure xxx_yyy_end           */
    IWORD       (*drv_alloc       )(); /* Ad procedure xxx_yyy_alloc         */
    IWORD       (*drv_free        )(); /* Ad procedure xxx_yyy_free          */
    IWORD       (*drv_open_device )(); /* Ad procedure xxx_yyy_open_device   */
    IWORD       (*drv_close_device)(); /* Ad procedure xxx_yyy_close_device  */
    IWORD       (*drv_alloc_sub   )(); /* Ad procedure xxx_yyy_alloc_sub     */
    IWORD       (*drv_free_sub    )(); /* Ad procedure xxx_yyy_free_sub      */
    IWORD       (*drv_connect     )(); /* Ad procedure xxx_yyy_connect       */
    IWORD       (*drv_listen      )(); /* Ad procedure xxx_yyy_listen        */
    IWORD       (*drv_disconnect  )(); /* Ad procedure xxx_yyy_disconnect    */
    IWORD       (*drv_abort       )(); /* Ad procedure xxx_yyy_abort         */
    IWORD       (*drv_write       )(); /* Ad procedure xxx_yyy_write         */
    IWORD       (*drv_read        )(); /* Ad procedure xxx_yyy_read          */
    IWORD       (*drv_setval      )(); /* Ad procedure xxx_yyy_setval        */
    IWORD       (*drv_getval      )(); /* Ad procedure xxx_yyy_getval        */
    IWORD       (*drv_rpc         )(); /* Ad procedure xxx_yyy_rpc           */

    INT             ntag             ; /* Nombre de tags.                    */
    INT             ntag_sub         ; /* Nombre de tags de sous-canaux.     */

    const UCHAR    *const *tag       ; /* Tableau adresses des noms des tags */
    const UCHAR    *const *val       ; /* Tableau des valeurs des tags ENUM. */
    const Ptag     *ptag             ; /* Tableau des proprietes des tags.   */
    const UINT      nreg_idev        ; /* Numero de registre, decalage dans  */
    const UINT      sreg_idev        ; /* dans ce registre et masque pour    */
    const UINT      mreg_idev        ; /* stocker le numero de device.       */
    const UCHAR     sc_size          ; /* Nombre de bits du sous-canal.      */

    UINT            alloc_flags_0    ; /* Flags d'ouvertures a 0             */
    UINT            alloc_flags_1    ; /* Flags d'ouvertures a 1             */
  END               Dps_driver       ; /* ---------------------------------- */

#else

typedef struct  dps_driver             /* Un driver/protocole/service        */
  BEGIN                                /* ---------------------------------- */
    CHAR            name[STDNAME]    ; /* Nom du driver/protocole/service    */
    CHAR            typdrv           ; /* 001:dcar 010:proto 011:ser 100:dblk*/

    IWORD         (*drv_evt   )()    ; /* Ad procedure xxx_yyy_evt           */
    IWORD         (*drv_info  )()    ; /* Ad procedure xxx_yyy_info          */
    IWORD         (*drv_init  )()    ; /* Ad procedure xxx_yyy_init          */
    IWORD         (*drv_end   )()    ; /* Ad procedure xxx_yyy_end           */
    IWORD         (*drv_open  )()    ; /* Ad procedure xxx_yyy_open          */
    IWORD         (*drv_close )()    ; /* Ad procedure xxx_yyy_close         */
    IWORD         (*drv_write )()    ; /* Ad procedure xxx_yyy_write         */
    IWORD         (*drv_read  )()    ; /* Ad procedure xxx_yyy_read          */
    IWORD         (*drv_setval)()    ; /* Ad procedure xxx_yyy_setval        */
    IWORD         (*drv_getval)()    ; /* Ad procedure xxx_yyy_getval        */
    IWORD         (*drv_connect   )(); /* Ad procedure xxx_yyy_connect       */
    IWORD         (*drv_disconnect)(); /* Ad procedure xxx_yyy_disconnect    */
    IWORD         (*drv_rpc       )(); /* Ad procedure xxx_yyy_rpc           */

    INT             ntag             ; /* Nombre de tags.                    */

    const UCHAR    *const *tag       ; /* Tableau adresses des noms des tags */
    const UCHAR    *const *val       ; /* Tableau des valeurs des tags ENUM. */
    const Ptag     *ptag             ; /* Tableau des proprietes des tags.   */

    UINT            open_flags_0     ; /* Flags d'ouvertures a 0             */
    UINT            open_flags_1     ; /* Flags d'ouvertures a 1             */
    UCHAR           open_nbreg       ; /* Autorise/interdit tags a drv_open  */
  END               Dps_driver       ; /* ---------------------------------- */

#endif


/*
    2.4 Structure d'iteration pour manipulation des listes de registres
    -------------------------------------------------------------------
*/


/*****************************************************************************
 * Voir drv_itf1.c section 2.13.                                             *
 *****************************************************************************/


typedef struct _s_rl_it                /*                                    */
  BEGIN                                /* ---------------------------------- */
    INT             nr               ; /* Numero de registre                 */
    INT             nbb              ; /* Nombre de blocs                    */
    INT             fmt              ; /* Format des donnees                 */
    INT             nbr              ; /* Nombre de registres dans le bloc   */
    UCHAR          *lr               ; /* Pointeur sur le bloc courant       */
    UCHAR          *ls               ; /* Pointeur sur le bloc suivant       */
    UCHAR           o[4]             ; /* 0123: Big endian, 3210: lil endian */
    UCHAR          *p                ; /* Pointeur registre dans la liste.   */
  END               Rlit             ; /* ---------------------------------- */


/*
    3    Public variables
    _____________________
*/


/*
    4    Prototypes of public procedures
    ____________________________________
*/


#ifdef _DRO_

IWORD drv_list_tags         (CHAR*,CHAR*,INT*,INT*                           );
IWORD drv_list_modules      (CHAR*,INT,INT*,INT,INT*                         );
IWORD drv_list_names        (CHAR*,CHAR*,INT*,INT,INT*                       );
IWORD drv_init_driver       (CHAR*,INT,INT*,INT*                             );
IWORD drv_init_protocol     (CHAR*,INT,INT,INT*,INT*                         );
IWORD drv_init_service      (CHAR*,INT,INT*,INT*                             );
IWORD drv_end               (INT,INT,INT*                                    );
IWORD drv_open_driver       (INT,CHAR*,CHAR*,INT,INT,INT,INT*,INT*           );
IWORD drv_open_protocol     (INT,CHAR*,CHAR*,INT,INT,INT,INT*,INT*           );
IWORD drv_open_service      (INT,CHAR*,INT[],INT,CHAR*,INT,INT,INT,INT*,INT* );
IWORD drv_close             (INT,INT,INT*                                    );
IWORD drv_connect           (INT,CHAR*,INT,INT,INT*                          );
IWORD drv_disconnect        (INT,CHAR*,INT,INT*                              );
IWORD drv_write             (INT,UCHAR*,INT,INT,INT,INT*                     );
IWORD drv_read              (INT,INT,UCHAR**,INT*,INT*,INT,INT*              );
IWORD drv_setval            (INT,CHAR*,INT,INT*                              );
IWORD drv_getval            (INT,CHAR*,INT,INT*                              );
IWORD drv_execute           (INT,CHAR*,INT,INT*                              );
IWORD drv_rpc               (INT,CHAR*,CHAR*,CHAR*,INT,INT*                  );
IWORD drv_getmajor          (CHAR*,INT*,INT*                                 );
IWORD drv_put               (INT,UCHAR*,UINT,UINT,INT,INT,INT,INT*           );
IWORD drv_get               (INT,UINT,UINT,INT,INT,UCHAR**,INT,INT*          );
IWORD drv_set_state         (S_evt*                                          );
IWORD tag2reg               (const Dps_driver*                                ,
                             CHAR*[4],UINT*,INT,INT*,INT*,INT*               );
IWORD tag2cmd               (const Dps_driver*,CHAR*,UINT*,UINT*             );
IWORD reg2tag               (const Dps_driver*,UINT*,UINT,CHAR*,INT,INT*     );
IWORD init_telecom          (void                                            );

void  unschedule            (INT,INT,IWORD(*)(),INT,S_evt**,IWORD*          );
IWORD set_rets              (INT                                             );

#else

IWORD drv_list_tags         (CHAR*,CHAR*,INT*,INT*                           );
IWORD drv_list_modules      (CHAR*,INT,INT*,INT,INT*                         );
IWORD drv_list_names        (CHAR*,CHAR*,INT*,INT,INT*                       );
IWORD drv_init_driver       (CHAR*,INT,INT,INT*,INT*                         );
IWORD drv_init_protocol     (CHAR*,INT,INT,INT*,INT*                         );
IWORD drv_init_service      (CHAR*,INT,INT*,INT*                             );
IWORD drv_end               (INT,INT,INT*                                    );
IWORD drv_alloc_device      (INT,CHAR*,CHAR*,CHAR*,INT,INT,INT,INT,INT*,INT* );
IWORD drv_alloc_protocol    (INT,CHAR*,CHAR*,INT,INT,INT,INT,INT*,INT*       );
IWORD drv_alloc_service     (INT,CHAR*,CHAR*,INT,INT,INT,INT,INT*,INT*       );
IWORD drv_free              (INT,INT,INT*                                    );
IWORD drv_open_device       (INT,CHAR*,INT,INT*                              );
IWORD drv_close_device      (INT,INT,INT*                                    );
IWORD drv_alloc_subchan     (INT,CHAR*,CHAR*,INT,INT,INT,INT,INT*,INT*       );
IWORD drv_free_subchan      (INT,INT,INT*                                    );
IWORD drv_connect           (INT,CHAR*,INT,INT*                              );
IWORD drv_listen            (INT,CHAR*,INT,INT*                              );
IWORD drv_disconnect        (INT,INT,INT,INT*                                );
IWORD drv_abort             (INT,INT,INT*                                    );
IWORD drv_write             (INT,UCHAR*,INT,INT,INT,INT,INT*                 );
IWORD drv_read              (INT,INT,INT,INT,UCHAR**,INT*,INT*,INT,INT*      );
IWORD drv_setval            (INT,CHAR*,INT,INT*                              );
IWORD drv_getval            (INT,CHAR*,INT,INT,INT*                          );
IWORD drv_getval2           (INT,CHAR*,INT,INT*                              );
IWORD drv_execute           (INT,CHAR*,INT,INT*                              );
IWORD drv_rpc               (INT,CHAR*,CHAR*,CHAR*,INT,INT,INT*              );
IWORD drv_rpc2              (INT,CHAR*,CHAR*,CHAR*,INT,INT*                  );
IWORD drv_getmajor          (CHAR*,INT*,INT*                                 );
IWORD drv_put               (INT,UCHAR*,UINT,UINT,INT,INT,INT,INT*           );
IWORD drv_get               (INT,UINT,UINT,INT,INT,UCHAR**,INT,INT*          );
IWORD drv_set_state         (S_evt*                                          );
IWORD tag2reg               (const Dps_driver*                                ,
                             INT,INT,CHAR*[4],UINT*,INT,INT*,INT*            );
IWORD tag2cmd               (const Dps_driver*,INT,INT,CHAR*,UINT*,UINT*     );
IWORD reg2tag               (const Dps_driver*,UINT*,UINT,CHAR*,INT,INT*     );
IWORD init_telecom          (void                                            );

void  unschedule            (INT,INT,IWORD(*)(),INT,S_evt**,IWORD*          );
IWORD set_rets              (INT                                             );

#endif


#endif                                 /* End of DRV_H.                      */
