/*
**  Myapp_tasks.c - Sample for code tasks in Nucle STM32L152RE ============  **
**                                                                           **
**  At start-up we spawn two tasks: a "producer" which sends a custom event  **
**  every 1 second; and a "consumer" which chooses to receive the event and  **
**  handles it.                                                              **
**  =======================================================================  **
*/


/* Includes files and external references ...................................*/

#include <stdtyp.l>                    /* HyperPanel definitions & constants.*/
#include <moteur.h>                    /* vmk.c and vmio.c interface         */
#include <drv.h>                       /* drv.c interface                    */
#include <automaton.h>                 /* Automaton definitions.             */
#include <rdrv.h>                      /* drv.c tags interface               */
#include <memoire.h>                   /* mem_buf.c interface                */
#include <hypstring.h>                 /* memcpy strcy .. interface          */
#include <text.h>                      /* Prototype hsprintf().              */
#include <keycode.h>                   /* Key codes from RCU                 */
#include <telecom.h>                   /* Constants and definitions for tags.*/
#include <engine.h>                    /* Constants for automatong engine.   */
#include <keym.txt>                    /* Applicative key codes              */
#include <systemm.txt>                 /* WAIT_CODERES                       */
#include <vmkm.txt>                    /* TSK_INIT_DATA TASK_INIT_BSS        */


/* Internal data types of the module ........................................*/

static int     producer_proc    (void*                                      ) ;
static int     consumer_proc    (void*                                      ) ;
static int     task_free        (void                                       ) ;

static void    open_asy         (void                                       ) ;
static void    close_asy        (void                                       ) ;
static void    write_asy        (int,unsigned char*,int                     ) ;

static void    wait_coderes     (int,int                                    ) ;


/* Internal defines of this module ------------------------------------------*/

#define  START                  10000  // Code for start event
#define  POKE                   10001  // Code for poke event
                                

/* Internal global variables of this module ---------------------------------*/

int            myapp_memuid          ; // Our memory user id

int            producer_stack[512]   ; // The stack of our task (512B)
int            producer_taskid       ; // Our task id

int            consumer_stack[512]   ; // The stack of our task (512B)
int            consumer_taskid       ; // Our task id

int            nb_tasks              ; // Number of tasks
int            start_rteid           ; // Route ID for START events
int            poke_rteid            ; // Route ID for POKE events
int            poke_id  = 0          ; // Identifier of poke

int            asy_modd              ; // MODD of the ASY driver
int            asy_iod               ; // IOD of devive ASY\DEV0
int            asy_rteid             ; // Route ID for ASY IND_REPORT evts

unsigned char  *buf_snd              ; // Address of DEV0 transmit buffer


/* Static data of this module -----------------------------------------------*/

static const char *asy_taglist    = "BAUDS=115200\nNBBITS=8\n"
                                    "STOPBIT=1\nPARITY=NONE"                ;

/* Beginning of the code ----------------------------------------------------

init_myapp          VMK Task creation function

producer_proc       Entry point for create_task - Producer main loop
consumer_proc       Entry point for create_task - Producer main loop
task_free           Termination function for create_task

open_asy            Open of two serial ports
close_asy           Close of two serial ports
write_asy           Blocking transmission on one serial line

wait_coderes        Wait one and only one event

*/


/*  Procedure init_myapp ------------------------------------------------------

    Purpose : Allocates task contexts and associated Logical Ways of
              the AUT_TASK automaton, then requests the start of the task.
*/

int init_myapp(char *mod,char*conf)
  {
    int             ret              ; // Returned code

/*****************************************************************************
 * Step 1 : The "create_task" procedure initializes all the data that is     *
 * ------   necessary for a new task, it allocates a task context and a      *
 *          logical way of the AUT_TASK automaton. This LW will be used  to  *
 *          receive all the events for that task. The returned identifier    *
 *          "taskid" is in fact equal to 0x12FFFF00 | LW, where LW is a      *
 *          Logical way number of AUT_TASK, and also an index in the context *
 *          table "task_ctx[]". The input parameters of "create_task" are    *
 *          stored into "task_ctx[LW]" :                                     *
 *          - The task entry point is always a C procedure and here our      *
 *            procedures are "consumer_proc" and "producer_proc".            *
 *          - In the event that the task entry point procedure returns, the  *
 *            VMK will call a "clean-up" procedure we have to provide. Here  *
 *            our termination procedure is "task_free".                      *
 *          - The stack addresses ("consumer_stack" and "producer_stack")    *
 *            and their sizes in bytes.                                      *
 *          - The task Prioritys and the task initialization flags           *
 *****************************************************************************/

    create_task("app"           ,      // Taskgroup name
                consumer_proc   ,      // Task entry point
                task_free       ,      // Tasm termination call-back
                consumer_stack  ,      // Stack address
                sizeof(consumer_stack),// Stack size in bytes
                PRIO_TSK_MIN    ,      // Task Priority
                HNULL           ,      // Parameter for "mytask_proc"
                TASK_INIT_BSS  +       // Init Flags
                TASK_INIT_DATA +       //
                TASK_INIT_CODE  ,      //
                &consumer_taskid  )  ; // Task_id = 0x12FFFF00 + LC

    create_task("app"           ,      // Taskgroup name
                producer_proc   ,      // Task entry point
                task_free       ,      // Tasm termination call-back
                producer_stack  ,      // Stack address
                sizeof(producer_stack),// Stack size in bytes
                PRIO_TSK_MIN    ,      // Task Priority
                HNULL           ,      // Parameter for "mytask_proc"
                TASK_INIT_BSS  +       // Init Flags
                TASK_INIT_DATA +       //
                TASK_INIT_CODE  ,      //
                &producer_taskid  )  ; // Task_id = 0x12FFFF00 + LC

    nb_tasks = 2                     ; // Number of tasks


/*****************************************************************************
 * Step 2 : Here the new task has been created but this does not implies it  *
 * ------   starts running. A call to "start_task" has to be issued. This    *
 *          procedure sends an event (RUN_TASK) that is a request to start   *
 *          task execution. This event is sent to the "*_taskid & 0xFF"      *
 *          logical way of automaton AUT_TASK.                               *
 *****************************************************************************/

    start_task(consumer_taskid,        // Send an event to VMK in order
               &ret            )     ; // to request the task start

    start_task(producer_taskid,        // Send an event to VMK in order
               &ret            )     ; // to request the task start


/*****************************************************************************
 * Step 3 : In order to be able to use the "alloc_buf" procedure one needs   *
 * ------   a user identifier from the allocation subsystem. We just have    *
 *          to make a call to "alloc_memuid", we get the identifier in the   *
 *          "myapp_memuid" global variable.                                  *
 *****************************************************************************/

    alloc_memuid(&myapp_memuid,        // Allocates a user id for alloc_buf
                 &ret          )     ; // and other allocation procedures


/****************************************************************************
 * Step 4 : Initialize the driver/protocol/services interface. Once done,   *
 * -------  the VMK "app" can use the driver/protocole/services interface   *
 *          through procedures named "drv_***". Those procedures are        *
 *          sending REQ_xyz events to the VMIO automatons.                  *
 ****************************************************************************/

    init_telecom()                   ; // Initialize driver/protocol/services
                                       // API

    return 0                         ; // Exit without any error
  }


/*  Procedure consumer_proc ---------------------------------------------------

    Purpose : This is consumer task main loop.
*/

static INT consumer_proc(void *param)
  {
    int             d, m, y          ; // Day, Month, Year
    int             h, mi, s, ms     ; // Hour, minutes, seconds, milliseconds
    int             ret              ; // Returned code

/*****************************************************************************
 * Step 1 : Here we initialize the needed drivers :                          *
 * ------   - The ASY driver, we are using here one serial port.             *
 *****************************************************************************/

    open_asy()                       ; // Open the two serial ports


/*****************************************************************************
 * Step 2 : Then we setup a route to catch the POKE event from the producer. *
 * ------                                                                    *
 *****************************************************************************/

    add_uroute(POKE, POKE ,            //
               -1, -1     ,            //
               0          ,            //
               &poke_rteid  )        ; //


/*****************************************************************************
 * Step 3 : Send a START event.                                              *
 * ------                                                                    *
 *****************************************************************************/

    route_uevent(START, 0, HNULL, 0, 0, 0, &ret) ;


/*****************************************************************************
 * Step 4 : We wait for a new event.                                         *
 * ------                                                                    *
 *****************************************************************************/

    loop :
    wait_coderes(POKE,-1)            ; //


/*****************************************************************************
 * Step 5 : Print something then loop back to step 4.                        *
 * ------                                                                    *
 *****************************************************************************/

    tim_get(&d  ,                      // day
            &m  ,                      // Month
            &y  ,                      // Year
            &h  ,                      // Hour (0..23)
            &mi ,                      // Minutes (0..59)
            &s  ,                      // Seconds (0..59)
            &ms   )                  ; // Milliseconds (0..999)

    hsprintf((char*)buf_snd,"%02d:%02d:%02d <%08X>\r\n",h,mi,s,task_evt.reqid) ;
    write_asy(asy_iod, buf_snd, 21) ;

    goto loop ;

    return 0                         ;
  }


/*  Procedure producer_proc ---------------------------------------------------

    Purpose : This is producer task main loop.
*/

static INT producer_proc(void *param)
  {

    int             ret              ; // Returned code

/*****************************************************************************
 * Step 1 : Add route for START event.                                       *
 * ------                                                                    *
 *****************************************************************************/

    add_uroute(START, START ,          //
               -1, -1       ,          //
               0            ,          //
               &start_rteid   )      ; //


/*****************************************************************************
 * Step 2 : Wait for START event from consumer and delete route when done.   *
 * ------                                                                    *
 *****************************************************************************/

    wait_coderes(START, -1)          ; // Unschedule until START
    del_uroute(&start_rteid, 1)      ; // Delete START route


/*****************************************************************************
 * Step 3 : Send a POKE event.                                               *
 * ------                                                                    *
 *****************************************************************************/

    loop:
    route_uevent(POKE, 0, HNULL, 0, poke_id++, 0, &ret) ;


/*****************************************************************************
 * Step 4 : Wait for 2 seconds, then loop to step 3.                         *
 * ------                                                                    *
 *****************************************************************************/

    waitevt_task(HNULL    ,            // Address of waiting list
                 0        ,            // Size of "waitlist[]"
                 2000     ,            // Wait 2000ms
                 0        ,            // Do not purge previous events
                 &ret       )        ; // Return code


    goto loop ;


    return 0                         ;
  }



/*  Procedure task_free -------------------------------------------------------

    Purpose : This is our task "clean-up" procedure for both tasks.
*/

static int task_free(void)
  {
    int             ret              ; // Procedurs return code

/*****************************************************************************
 * Step 1 : We decrement number of running tasks. If last task of this app   *
 * ------   is dead, we continue with step 2.                                *
 *****************************************************************************/

    if (--nb_tasks)                    // If a task is still running,
      goto end                       ; // we skip step 2.

/*****************************************************************************
 * Step 2 : We free the memory user identifier that was allocated by the     *
 * ------   "init_myapp" procedure.                                          *
 *****************************************************************************/

    free_memuid(myapp_memuid,          // Frees a user id for alloc_buf
                0x00000007  ,          // mask = buffers/links/huge
                &ret          )      ; //

    end                              : // Early exit.

    return 0                         ;
  }


/*  Procedure open_asy --------------------------------------------------------

    Purpose : Initialize the code of the ASY driver and then opens the two 
              serial port that are available. The module identifier of the
              ASY driver is stored in "asy_modd" whilst the two opened devices
              descriptors (Input/Output Descriptors") are kept in "asy_iod0" 
              and "asy_iod1" respectively. Line parameters (speed, nbbits and
              parity) are set. Then we allocate for each controller one
              transmit buffer.
*/

static void open_asy(void)
  {
    int             ret              ; // Procedures returned code

/*****************************************************************************
 * Step 1 : We have to initialize the piece of code that is the ASY driver   *
 * ------   before allocating devices that its manages. We have to use       *
 *          "drv_init_driver" that sends an REQ_INIT to the driver. The      *
 *          driver is not located here as we are in the Application container*
 *          but inside the IO container. We the REQ_INIT event request will  *
 *          have been processed by the AUT_ASY VMIO automaton, it will send  *
 *          us back a RESP_INIT response event. Here we decide to be         *
 *          unscheduled until the RESP_INIT event is received                *
 *****************************************************************************/

    drv_init_driver("ASY"     ,        // VMIO driver name
                    0         ,        // Node number = local (0)
                    1         ,        // reqid value
                    &asy_modd ,        // Module identifier
                    &ret       )     ; // Error code


/*****************************************************************************
 * Step 2 : Now that VMIO ASY driver is ready, we can now issue REQ_ALLOC    *
 * ------   requests to it, in order to allocate the two available USARTS    *
 *          We use "drv_alloc_device" that sends a REQ_ALLOC request event   *
 *          to the VMIO AUT_ASY automaton, we we ask to be unscheduled       *
 *          until the RESP_ALLOC response event is received from the IO      *
 *          container                                                        *
 *****************************************************************************/

    drv_alloc_device(asy_modd    ,     // Module Descriptor Id
                     "ASY\\DEV0" ,     // Device name = DEV0
                     ""          ,     // Tagini  = empty
                     ""          ,     // Taglist = empty
                     NBLOCKING_IO,     // Flags
                     2           ,     // Reqid
                     0           ,     // Route ID   = empty
                     0           ,     // Route ID 2 = empty
                     &asy_iod    ,     // Returned I/O descriptor
                     &ret         )  ; // Return code


/*****************************************************************************
 * Step 3 : Now we have allocated both serial ports, we have a special thing *
 * ------   to do in order to receive unsollicited events IND_REPORT. For a  *
 *          serial port, when a state change of the CTS control signal will  *
 *          occur, then the ASY driver will issue a IND_REPORT. This event   *
 *          will be written into the external VMK waiting queue. Then the    *
 *          VMK will copy that event in each task waiting queue that has     *
 *          created a route that matches with this event. If there is no     *
 *          matching route, the event will not be copied in any task event   *
 *          wiating queue. But here we want to receive IND_REPORT events     *
 *          are comming from both "asy_iod0" and "asy_iod1". We cas create   *
 *          a unique route that will "catch" the IND_REPORTs events with a   *
 *          "reserve" value between MIN(asy_iod0) and MAX(asy_iod1)          *
 *****************************************************************************/

    add_uroute(IND_REPORT ,            // Min value for "code"
               IND_REPORT ,            // Max value for "code"
               asy_iod    ,            // Min value for "reserve"
               asy_iod    ,            // Max value for "reserve"
               0          ,            // Flags
               &asy_rteid  )         ; // Route identifier


/*****************************************************************************
 * Step 4 : Here we initialize the hardware of the two serial ports. To do   *
 * ------   this, we have to call "device_open_device. This procedures sends *
 *          a REQ_OPEN event to the AUT_ASY automaton that is located inside *
 *          the IO container. Then we ask to be unscheduled until the        *
 *          VMIO AUT_ASY automaton sends us the RESP_OPEN response event     *
 *****************************************************************************/

    drv_open_device(asy_iod     ,      // I/O descriptor
                    ""          ,      // Taglist = empty
                    3           ,      // Reqid
                    &ret          )  ; // Return code


/*****************************************************************************
 * Step 5 : Set line parameters for the two serial line controllers. We have *
 * ------   to call the "drv_setval" procedure. This procedure sends a       *
 *          REQ_SETVAL request event the the AUT_ASY VMIO automaton. Then    *
 *          we unschedule until the RESP_SETVAL response event is received   *
 *****************************************************************************/

    drv_setval(asy_iod             ,   // I/O descriptor for DEV0
               (char*)asy_taglist  ,   // taglist
               6                   ,   // Reqid
               &ret                 ); // Return code 


/*****************************************************************************
 * Step 6 : Allocates memory buffers for transmit, one for DEV0 and another  *
 * -------  one for DEV1. We store the buffers addresses in "buf_snd0" and   *
 *          "buf-snd1". It has to be noted that we do not allocate any       *
 *          receive buffer, because this is done by the ASY driver. When the *
 *          VMIO AUT_ASY receives a REQ_REQ, this event contains a number    *
 *          of allowaed receive tokens and receive buffer allocation is done *
 *          by AUT_ASY. So the present module does not contains any call     *
 *          to "alloc_buf" regarding receive buffers.                        *
 *****************************************************************************/

    alloc_buf(myapp_memuid ,           // Memory user id
              80           ,           // Size in bytes of requested buffer
              0            ,           // Flags
              &buf_snd     ,           // Address of allocated buffer
              &ret          )        ; // Return code


  }


/*  Procedure close_asy -------------------------------------------------------

    Purpose : This procedure closes the two USART, then frees those two 
              devices, terminates the ASY module, delete the route that has 
              been created for the IND_REPORT events, and finally frees the 2 
              telecom buffers that were allocated by "open_asy".
*/

static void close_asy(void)
  {

    int             list[2]          ; // Parameter for "del_uroute"
    int             ret              ; // Return code

/*****************************************************************************
 * Step 1 : Close the two serial ports controller devices. We have to call   *
 * ------   "drv_close_device" for DEV0 (so asy_iod0) and DEV1 (so asy_iod1) *
 *          This procedure sends a REQ_CLOSE request event to the VMIO       *
 *          AUT_ASY automaton and here we unschedule until the corresponding *
 *          RESP_CLOSE, sent by AUT_ASY, is received                         *
 *****************************************************************************/

    drv_close_device(asy_iod  ,        // IOD of the device to be closed
                     1        ,        // Reqid
                     &ret      )     ; // Return code


/*****************************************************************************
 * Step 2 : Free the two serial port controller devices. We have to send to  *
 * ------   AUT_ASY a REQ_FREE request event for each. We have to call the   *
 *          "drv_free" procedure to do that. Then, we unschedule until the   *
 *          RESP_FREE response event is received.                            *
 *****************************************************************************/

    drv_free(asy_iod  ,                // IOD of the device to be freed
             3        ,                // reqid
             &ret       )            ; // Return code


/*****************************************************************************
 * Step 3 : Terminates the ASY driver. We have to send to the AUT_ASY VMIO   *
 * -------  automaton a REQ_END request event. This is done with a call to   *
 *          the "drv_end" procedure. The AUT_ASY VMIO automaton receives     *
 *          this event and then sends back a RESP_END respense event. Here,  *
 *          we unschedule until the RESP_END response event is received      *
 *****************************************************************************/

    drv_end(asy_modd ,                 // MODD of the module to be ended
            5        ,                 // Reqid
            &ret       )             ; // Return code


/*****************************************************************************
 * Step 4 : Delete the route we were using for IND_REPORT events. We have    *
 * -------  to call the "del_uroute" procedure. As this procedure takes as   *
 *          in put an array containing a list of route identifiers, we use   *
 *          here an array of one entr in which we store "asy_rteid" before   *
 *          calling "del_uroute"                                             *
 *          ---------------------------------------------------------------- *
 *          We could directly call "del_route" with the address of the       *
 *          "asy_rteid" global variable because there is no difference       *
 *          between a variable adress and an array address                   *
 *****************************************************************************/

    list[0] = asy_rteid              ; // Store "asy_rteid" in a one entry
                                       // array
    del_uroute(list ,                  // We call "del_uroute" with a list
               1     )               ; // of route identifers tant only
                                       // contains one element.

/*****************************************************************************
 * Step 5 : Free the 2 memory buffers that were allocated by "open_asy".     *
 * ------   For each of them, we just call the "free_buffer" procedure       *
 *****************************************************************************/

    free_buf(buf_snd, &ret )         ; // Free "buf_snd"

  }



/*  Procedure write_asy  ------------------------------------------------------

    Purpose : Prints (sends) on the serial line one buffer. This is a blocking
              procedure, we are unscheduled until the end of transmission
*/

static void write_asy(int iod, unsigned char *buf, int lg)
  {
    int             ret              ; // Return code

/*****************************************************************************
 * Step 1 : Send using serial controller "iod" the "lg" bytes that are       *
 * ------   in telecom buffer ponted by "buf".  We call the "drv_write"      *
 *          procedure that sends a REQ_WRITE request event to the AUT_ASY    *
 *          VMIO automaton. 
 *****************************************************************************/

    drv_write(iod       ,              // IOD of serial controller DEV0
              buf       ,              // Buffer Address
              0         ,              // Buffer Offset
              lg        ,              // Number of bytes to be sent
              0         ,              // Flags
              1         ,              // Reqid
              &ret       )           ; // Return code


/*****************************************************************************
 * Step 2 : We unschedule until the RESP_WRITE event is received. This event *
 * ------   is sent by AUY_ASY only when the last byte as been sent on the   *
 *          serial line and not before                                       *
 *****************************************************************************/

    wait_coderes(RESP_WRITE,iod)     ; // Unschedule until the RESP_WRITE
                                       // event is received.
  }



/*  Procedure wait_coderes ----------------------------------------------------

    Purpose : Unschedule until one specific event is received. If non awaited
              events are received meanwhile, they will be kept inside the task
              events waiting queue.
*/

static void wait_coderes(int code, int res)
  {
    int             ret              ; // Return code
    int             waitlist[1][3]   ; // Parameter of "waitevt_task

/*****************************************************************************
 * Step 1 : We build a list of a single pair (code,reserve). The task will   *
 * ------   be unschedule until an event corresponding to the one expected   *
 *          is received by the task. This wait may be infinite if the event  *
 *          is never received.                                               *
 *****************************************************************************/

    waitlist[0][0]  = WAIT_CODERES   ; // Test "code" and "reserve" fields
    waitlist[0][1]  = code           ; // The awaited value for "code"
    waitlist[0][2]  = res            ; // The awaited value for "reserve"

    waitevt_task(waitlist ,            // Address of waiting list
                 1        ,            // Size of "waitlist[]"
                 0        ,            // No maximum waiting time
                 0        ,            // Do not purge previous events
                 &ret       )        ; // Return code
  }


