/*
**  Myhello.c - Sample code for Nucleo STM32L152RE ========================  **
**                                                                           **
**  This simple code is located into the Application Container, it is run    **
**  by the VMK sub-operation system. On the other hand, the I/O container    **
**  runs the ASY (Asynchronous Lines) driver.                                **
**  Drivers are   run by the VMIO sub-operating system.                      **
**                                                                           **
**  This application is using the driver/protocol/service API to send        **
**  requests to the drivers. Those requests are in fact event messages that  **
**  are received by the automatons located inside the I/O container.         **
**                                                                           **
**  The goal of this small aplication is to write a single message           **
**  "Hello World since :hh:mm:ss" each seconde on the serial port            **
**                                                                           **
**  =======================================================================  **
*/


/* Includes files and external references ...................................*/

#include <stdtyp.l>                    /* HyperPanel definitions & constants.*/
#include <moteur.h>                    /* vmk.c and vmio.c interface         */
#include <drv.h>                       /* drv.c interface                    */
#include <automaton.h>                 /* Automaton definitions.             */
#include <rdrv.h>                      /* drv.c tags interface               */
#include <memoire.h>                   /* mem_buf.c interface                */
#include <hypstring.h>                 /* memcpy strcy .. interface          */
#include <text.h>                      /* Prototype hsprintf().              */
#include <telecom.h>                   /* Constants and definitions for tags.*/
#include <engine.h>                    /* Constants for automatong engine.   */
#include <keym.txt>                    /* Applicative key codes              */
#include <systemm.txt>                 /* WAIT_CODERES                       */
#include <vmkm.txt>                    /* TSK_INIT_DATA TASK_INIT_BSS        */


/* Internal data types of the module ........................................*/

static int     mytask_proc      (void*                                      ) ;
static int     pg_main          (int                                        ) ;
static int     pg_asy_opts      (int                                        ) ;
static int     pg_asy_baud      (int                                        ) ;
static int     pg_asy_bits      (int                                        ) ;
static int     pg_asy_stop      (int                                        ) ;
static int     pg_asy_parity    (int                                        ) ;
static int     pg_asy_flowctl   (int                                        ) ;
static int     pg_asy_flushcnd  (int                                        ) ;
static int     pg_asy_tempo     (int                                        ) ;
static int     myfree_proc      (void                                       ) ;

static void    open_asy         (void                                       ) ;
static void    close_asy        (void                                       ) ;
static void    give_asy_token   (int,int,int,int*                           ) ;
static void    write_asy        (int,unsigned char*,int                     ) ;
static void    set_asy          (int,const char*                            ) ;
static void    set_asy1_state   (void                                       ) ;
static void    send_asy_msg     (int,unsigned char*,int,int*                ) ;
static void    print_time       (void                                       ) ;

static int     ev_asy0_rcv      (void                                       ) ;
static int     ev_asy0_snd      (void                                       ) ;
static int     ev_asy1_rcv      (void                                       ) ;
static int     ev_asy1_snd      (void                                       ) ;
static void    set_asy1_state   (void                                       ) ;
static void    send_asy_msg     (int,unsigned char*,int,int*                ) ;

static void    wait_coderes     (int,int                                    ) ;
static int     wait_myevents    (void                                       ) ;


/* Internal defines of this module ------------------------------------------*/

#define  TICK                   10000  // Code for tick event
                                
#define  EV_ASY0_RCV                0  // Incoming data on ASY\DEV0
#define  EV_ASY1_RCV                1  // Incoming data on ASY\DEV1
#define  EV_ASY0_SND                2  // Sent data on ASY\DEV0
#define  EV_ASY1_SND                3  // Sent data on ASY\DEV1
#define  EV_MSEC                   40  // "msec" milliseconds
                                
#define  OPT_TIME                 100  // Hidden option (timeout)
#define  OPT_INVALID               -1  // Invalid menu option
#define  OPT_IGNORE                -2  // Simply ignore

#define  TRT_IGNORE                -1  // Do nothing
                                   
                                   
#define  TRT_RESTART               10  // Warm restart
#define  TRT_PRINT_TIME            11  // Refresh time
                                   

/* Internal global variables of this module ---------------------------------*/

int            mystack[512]          ; // The stack of our task (2kB)
int            myapp_taskid          ; // Our task id
int            myapp_memuid          ; // Our memory user id

int            idto                  ; // Timer identifier

int            asy_modd              ; // MODD of the ASY driver
int            asy_iod0              ; // IOD of devive ASY\DEV0
int            asy_iod1              ; // IOD of device ASY\DEV1
int            asy_rteid             ; // Route ID for ASY IND_REPORT evts

unsigned char  *buf_snd0             ; // Address of DEV0 transmit buffer
unsigned char  *buf_rcv0             ; // Address of DEV0 received buffer
int            tok_rcv0 = 0          ; // Number of receive tokens for DEV0

unsigned char  *buf_snd1             ; // Address of DEV1 transmit buffer
unsigned char  *buf_rcv1             ; // Address of DEV1 received buffer
int            tok_rcv1 = 0          ; // Number of receive tokens for DEV1
int            msg_snd1 = 0          ; // Number of sending messages for DEV1


unsigned char  state [5]             ; // State of menu variables
unsigned char  config[9]             ; // Current serial configuration



/* Static data of this module -----------------------------------------------*/

static const char *asy_taglist0   = "BAUDS=115200\nNBBITS=8\n"
                                    "STOPBIT=1\nPARITY=NONE"                ;
static const char *asy_taglist1   = "BAUDS=9600\nNBBITS=8\n"
                                    "STOPBIT=1\nPARITY=NONE\nBUFSIZE=0\n"
                                    "FLOWCTL=NONE\nTMODE=NONE\nTEMPO=1"     ;

/* Beginning of the code ----------------------------------------------------

init_myapp          VMK Task creation function
mytask_proc         Entry point for create_task - Main event loop
myfree_proc         Termination function for create_task

open_asy            Open of two serial ports
close_asy           Close of two serial ports
give_asy_token      Give one or more receive token to ASY driver
write_asy           Blocking transmission on one serial line
set_asy             Set a parameter of one serial line
set_asy1_state      Start/Stop sending messages
send_asy_msg        Non blocking sending of one serial message

ev_asy0_rcv         EV_ASY0_RCV  has been received - Determine command
ev_asy0_snd         EV_ASY0_SND  has been received - Determine command
ev_asy1_rcv         EV_ASY1_RCV  has been received - Determine command
ev_asy1_snd         EV_ASY1_SND  has been received - Determine command

wait_coderes        Wait one and only one event
wait_myevents       Wait for all my events

*/


/*  Procedure init_myapp ------------------------------------------------------

    Purpose : Allocates a task context and an associated Logical Way of
              the AUT_TASK automaton, then requests the start of the task.
*/

int init_myapp(char *mod,char*conf)
  {
    int             ret              ; // Returned code

/*****************************************************************************
 * Step 1 : The "create_task" procedure initializes all the data that is     *
 * ------   necessary for a new task, it allocates a task context and a      *
 *          logical way of the AUT_TASK automaton. This LW will be used  to  *
 *          receive all the events for that task. The returned identifier    *
 *          "taskid" is in fact equal to 0x12FFFF00 | LW, where LW is a      *
 *          Logical way number of AUT_TASK, and also an index in the context *
 *          table "task_ctx[]". The input parameters of "create_task" are    *
 *          stored into "task_ctx[LW]" :                                     *
 *          - The task entry point is always a C procedure and here our      *
 *            procedure is "mytask_proc".                                    *
 *          - In the event that the task entry point procedure returns, the  *
 *            VMK will call a "clean-up" procedure we have to provide. Here  *
 *            our termination procedure is "myfree_proc".                    *
 *          - The stack address ("mystack") and its size in bytes.           *
 *          - The task Priority and the task initialization flags            *
 *****************************************************************************/

    create_task("app"           ,      // Taskgroup name
                mytask_proc     ,      // Task entry point
                myfree_proc     ,      // Tasm termination call-back
                mystack         ,      // Stack address
                sizeof(mystack) ,      // Stack size in bytes
                PRIO_TSK_MIN    ,      // Task Priority
                HNULL           ,      // Parameter for "mytask_proc"
                TASK_INIT_BSS  +       // Init Flags
                TASK_INIT_DATA +       //
                TASK_INIT_CODE  ,      //
                &myapp_taskid     )  ; // Task_id = 0x12FFFF00 + LC


/*****************************************************************************
 * Step 2 : Here the new task has been created but this does not implies it  *
 * ------   starts running. A call to "start_task" has to be issued. This    *
 *          procedure sends an event (RUN_TASK) that is a request to start   *
 *          task execution. This event is sent to the "myapp_task_id & 0xFF" *
 *          logical way of automaton AUT_TASK.                               *
 *****************************************************************************/

    start_task(myapp_taskid,           // Send an event to VMK in order
               &ret          )       ; // to request the task start


/*****************************************************************************
 * Step 3 : In order to be able to use the "alloc_buf" procedure one needs   *
 * ------   a user identifier from the allocation subsystem. We just have    *
 *          to make a call to "alloc_memuid", we get the identifier in the   *
 *          "myapp_memuid" global variable.                                  *
 *****************************************************************************/

    alloc_memuid(&myapp_memuid,        // Allocates a user id for alloc_buf
                 &ret          )     ; // and other allocation procedures


/****************************************************************************
 * Step 4 : Initialize the driver/protocol/services interface. Once done,   *
 * -------  the VMK "app" can use the driver/protocole/services interface   *
 *          through procedures named "drv_***". Those procedures are        *
 *          sending REQ_xyz events to the VMIO automatons.                  *
 ****************************************************************************/

    init_telecom()                   ; // Initialize driver/protocol/services
                                       // API

    return 0                         ; // Exit without any error
  }


/*  Procedure mytask_proc -----------------------------------------------------

    Purpose : This is our task main loop.
*/

static INT mytask_proc(void *param)
  {
    int             ev               ; // Our event

/*****************************************************************************
 * Step 1 : Here we initialize the needed drivers :                          *
 * ------   - The ASY driver, we are using here two serial port contollers.  *
 *****************************************************************************/

    start                            :

    open_asy()                       ; // Open the two serial ports

    give_asy_token(asy_iod0  ,         // I/O descriptor
                   2         ,         // Number of receive token
                   1         ,         // Size of receive buffer
                   &tok_rcv0   )     ; // Counter of given tokens

    give_asy_token(asy_iod1 ,          // I/O descriptor
                   2        ,          // Number of receive token
                   8        ,          // Size of receive buffer
                   &tok_rcv1  )      ; // Counter of given tokens

/*****************************************************************************
 * Step 2 : We initialize printing state for menu, initial configuration of  *
 * ------   serial line and we print info through ASY\DEV0.              *
 *****************************************************************************/

    print_time()                     ; // Update time


/*****************************************************************************
 * Step 3 : We start a timer that will send us an event every 1 second so    *
 * ------   that we can update the time.                                     *
 *****************************************************************************/

    set_tto(CLOCK      ,               // Timer mode: clock
            1000       ,               // Duration in milliseconds
            TICK       ,               // Event code
            0          ,               // Event reserve field
            &idto        )           ; // Timer identifier


/*****************************************************************************
 * Step 4 : Here is our main event loop. For each loop, we do as follows :   *
 * -------  - First we wait for an event.                                    *
 *          - Then in ths case we execute the timer event each 1 seconde     *
 *****************************************************************************/

    wait_ev                          :

    ev = wait_myevents()             ; // Unschedule until an event is
                                       // received
    switch ( ev )
      {

        case EV_MSEC                 : // 1000 sec have been elapsed
          print_time()               ; // Update time
          break                      ;

        case TRT_RESTART             : // Warm_restart
          goto restart               ;


        default                      : // Anything else we want to ignore
          break                      ;

      }

    goto wait_ev                     ; // Wait for the next event


/*****************************************************************************
 * Step 5 : Close the  ASY                                                   *
 * ------                                                                    *
 *****************************************************************************/

    restart                          :

    clear_tto(idto)                  ; // Stop the timer
    close_asy()                      ; // Close the two serial ports

    goto start                       ;

    return 0                         ;
  }



/*  Procedure myfree_proc -----------------------------------------------------

    Purpose : This is our task "clean-up" procedure
*/

static int myfree_proc(void)
  {
    int             ret              ; // Procedurs return code

/*****************************************************************************
 * Step 1 : We free the memory user identifier that was allocated by the     *
 * ------   "init_myapp" procedure.                                          *
 *****************************************************************************/

    free_memuid(myapp_memuid,          // Frees a user id for alloc_buf
                0x00000007  ,          // mask = buffers/links/huge
                &ret          )      ; //
    return 0                         ;
  }


/*  Procedure open_asy --------------------------------------------------------

    Purpose : Initialize the code of the ASY driver and then opens the two 
              serial port that are available. The module identifier of the
              ASY driver is stored in "asy_modd" whilst the two opened devices
              descriptors (Input/Output Descriptors") are kept in "asy_iod0" 
              and "asy_iod1" respectively. Line parameters (speed, nbbits and
              parity) are set. Then we allocate for each controller one
              transmit buffer.
*/

static void open_asy(void)
  {
    int             ret              ; // Procedures returned code
    int             min_iod          ; // MIN(asy_iod0,asy_iod1)
    int             max_iod          ; // MAX(asy_iod0,asy_iod1)
    int             i                ; // Loop index to fill send buffer

/*****************************************************************************
 * Step 1 : We have to initialize the piece of code that is the ASY driver   *
 * ------   before allocating devices that its manages. We have to use       *
 *          "drv_init_driver" that sends an REQ_INIT to the driver. The      *
 *          driver is not located here as we are in the Application container*
 *          but inside the IO container. We the REQ_INIT event request will  *
 *          have been processed by the AUT_ASY VMIO automaton, it will send  *
 *          us back a RESP_INIT response event. Here we decide to be         *
 *          unscheduled until the RESP_INIT event is received                *
 *****************************************************************************/

    drv_init_driver("ASY"     ,        // VMIO driver name
                    0         ,        // Node number = local (0)
                    1         ,        // reqid value
                    &asy_modd ,        // Module identifier
                    &ret       )     ; // Error code


/*****************************************************************************
 * Step 2 : Now that VMIO ASY driver is ready, we can now issue REQ_ALLOC    *
 * ------   requests to it, in order to allocate the two available USARTS    *
 *          We use "drv_alloc_device" that sends a REQ_ALLOC request event   *
 *          to the VMIO AUT_ASY automaton, we we ask to be unscheduled       *
 *          until the RESP_ALLOC response event is received from the IO      *
 *          container                                                        *
 *****************************************************************************/

    drv_alloc_device(asy_modd    ,     // Module Descriptor Id
                     "ASY\\DEV0" ,     // Device name = DEV0
                     ""          ,     // Tagini  = empty
                     ""          ,     // Taglist = empty
                     NBLOCKING_IO,     // Flags
                     2           ,     // Reqid
                     0           ,     // Route ID   = empty
                     0           ,     // Route ID 2 = empty
                     &asy_iod0   ,     // Returned I/O descriptor
                     &ret         )  ; // Return code

    drv_alloc_device(asy_modd    ,     // Module Descriptor Id
                     "ASY\\DEV1" ,     // Device name = DEV1
                     ""          ,     // Tagini  = empty
                     ""          ,     // Taglist = empty
                     NBLOCKING_IO,     // Flags
                     3           ,     // Reqid
                     0           ,     // Route ID   = empty
                     0           ,     // Route ID 2 = empty
                     &asy_iod1   ,     // Returned I/O descriptor
                     &ret         )  ; // Return code


/*****************************************************************************
 * Step 3 : Now we have allocated both serial ports, we have a special thing *
 * ------   to do in order to receive unsollicited events IND_REPORT. For a  *
 *          serial port, when a state change of the CTS control signal will  *
 *          occur, then the ASY driver will issue a IND_REPORT. This event   *
 *          will be written into the external VMK waiting queue. Then the    *
 *          VMK will copy that event in each task waiting queue that has     *
 *          created a route that matches with this event. If there is no     *
 *          matching route, the event will not be copied in any task event   *
 *          wiating queue. But here we want to receive IND_REPORT events     *
 *          are comming from both "asy_iod0" and "asy_iod1". We cas create   *
 *          a unique route that will "catch" the IND_REPORTs events with a   *
 *          "reserve" value between MIN(asy_iod0) and MAX(asy_iod1)          *
 *****************************************************************************/

    min_iod = asy_iod0 < asy_iod1 ?    // Compute minimum value for "reserve"
              asy_iod0            :    // field of incoming events
              asy_iod1               ; //

    max_iod = asy_iod0 > asy_iod1 ?    // Compute maximum value for "reserve"
              asy_iod0            :    // field of incoming events
              asy_iod1               ; //

    add_uroute(IND_REPORT ,            // Min value for "code"
               IND_REPORT ,            // Max value for "code"
               min_iod    ,            // Min value for "reserve"
               max_iod    ,            // Max value for "reserve"
               0          ,            // Flags
               &asy_rteid  )         ; // Route identifier


/*****************************************************************************
 * Step 4 : Here we initialize the hardware of the two serial ports. To do   *
 * ------   this, we have to call "device_open_device. This procedures sends *
 *          a REQ_OPEN event to the AUT_ASY automaton that is located inside *
 *          the IO container. Then we ask to be unscheduled until the        *
 *          VMIO AUT_ASY automaton sends us the RESP_OPEN response event     *
 *****************************************************************************/

    drv_open_device(asy_iod0    ,      // I/O descriptor
                    ""          ,      // Taglist = empty
                    4           ,      // Reqid
                    &ret          )  ; // Return code

    drv_open_device(asy_iod1    ,      // I/O descriptor
                    ""          ,      // Taglist = empty
                    5           ,      // Reqid
                    &ret          )  ; // Return code


/*****************************************************************************
 * Step 5 : Set line parameters for the two serial line controllers. We have *
 * ------   to call the "drv_setval" procedure. This procedure sends a       *
 *          REQ_SETVAL request event the the AUT_ASY VMIO automaton. Then    *
 *          we unschedule until the RESP_SETVAL response event is received   *
 *****************************************************************************/

    drv_setval(asy_iod0            ,   // I/O descriptor for DEV0
               (char*)asy_taglist0 ,   // taglist
               6                   ,   // Reqid
               &ret                 ); // Return code 

    drv_setval(asy_iod1            ,   // I/O descriptor for DEV1
               (char*)asy_taglist1 ,   // taglist
               7                   ,   // Reqid
               &ret                 ); // Return code 


/*****************************************************************************
 * Step 6 : Allocates memory buffers for transmit, one for DEV0 and another  *
 * -------  one for DEV1. We store the buffers addresses in "buf_snd0" and   *
 *          "buf-snd1". It has to be noted that we do not allocate any       *
 *          receive buffer, because this is done by the ASY driver. When the *
 *          VMIO AUT_ASY receives a REQ_REQ, this event contains a number    *
 *          of allowaed receive tokens and receive buffer allocation is done *
 *          by AUT_ASY. So the present module does not contains any call     *
 *          to "alloc_buf" regarding receive buffers.                        *
 *****************************************************************************/

    alloc_buf(myapp_memuid ,           // Memory user id
              1500         ,           // Size in bytes of requested buffer
              0            ,           // Flags
              &buf_snd0    ,           // Address of allocated buffer
              &ret          )        ; // Return code

    alloc_buf(myapp_memuid ,           // Memory user id
              256          ,           // Size in bytes of requested buffer
              0            ,           // Flags
              &buf_snd1    ,           // Address of allocated buffer
              &ret          )        ; // Return code

/*****************************************************************************
 * Step 7 : We will send a continuous byte stream through ASY\DEV1 when      *
 * ------   enabled, to test throughput. We initialize the send buffer once  *
 *          for all with bytes from 0xFF to 0x00.                            *
 *****************************************************************************/

    for (i = 0 ; i < 256  ; i++)       // Fill up the send buffer with
      buf_snd1[i] = ~i & 0xFF        ; // bytes from 0xFF to 0x00.

  }


/*  Procedure close_asy -------------------------------------------------------

    Purpose : This procedure closes the two USART, then frees those two 
              devices, terminates the ASY module, delete the route that has 
              been created for the IND_REPORT events, and finally frees the 2 
              telecom buffers that were allocated by "open_asy".
*/

static void close_asy(void)
  {

    int             list[2]          ; // Parameter for "del_uroute"
    int             ret              ; // Return code

/*****************************************************************************
 * Step 1 : Close the two serial ports controller devices. We have to call   *
 * ------   "drv_close_device" for DEV0 (so asy_iod0) and DEV1 (so asy_iod1) *
 *          This procedure sends a REQ_CLOSE request event to the VMIO       *
 *          AUT_ASY automaton and here we unschedule until the corresponding *
 *          RESP_CLOSE, sent by AUT_ASY, is received                         *
 *****************************************************************************/

    drv_close_device(asy_iod0 ,        // IOD of the device to be closed
                     1        ,        // Reqid
                     &ret      )     ; // Return code

    drv_close_device(asy_iod1 ,        // IOD of the device to be closed
                     2        ,        // Reqid
                     &ret      )     ; // Return code


/*****************************************************************************
 * Step 2 : Free the two serial port controller devices. We have to send to  *
 * ------   AUT_ASY a REQ_FREE request event for each. We have to call the   *
 *          "drv_free" procedure to do that. Then, we unschedule until the   *
 *          RESP_FREE response event is received.                            *
 *****************************************************************************/

    drv_free(asy_iod0 ,                // IOD of the device to be freed
             3        ,                // reqid
             &ret       )            ; // Return code

    drv_free(asy_iod1 ,                // IOD of the device to be freed
             4        ,                // reqid
             &ret       )            ; // Return code


/*****************************************************************************
 * Step 3 : Terminates the ASY driver. We have to send to the AUT_ASY VMIO   *
 * -------  automaton a REQ_END request event. This is done with a call to   *
 *          the "drv_end" procedure. The AUT_ASY VMIO automaton receives     *
 *          this event and then sends back a RESP_END respense event. Here,  *
 *          we unschedule until the RESP_END response event is received      *
 *****************************************************************************/

    drv_end(asy_modd ,                 // MODD of the module to be ended
            5        ,                 // Reqid
            &ret       )             ; // Return code


/*****************************************************************************
 * Step 4 : Delete the route we were using for IND_REPORT events. We have    *
 * -------  to call the "del_uroute" procedure. As this procedure takes as   *
 *          in put an array containing a list of route identifiers, we use   *
 *          here an array of one entr in which we store "asy_rteid" before   *
 *          calling "del_uroute"                                             *
 *          ---------------------------------------------------------------- *
 *          We could directly call "del_route" with the address of the       *
 *          "asy_rteid" global variable because there is no difference       *
 *          between a variable adress and an array address                   *
 *****************************************************************************/

    list[0] = asy_rteid              ; // Store "asy_rteid" in a one entry
                                       // array
    del_uroute(list ,                  // We call "del_uroute" with a list
               1     )               ; // of route identifers tant only
                                       // contains one element.

/*****************************************************************************
 * Step 5 : Free the 2 memory buffers that were allocated by "open_asy".     *
 * ------   For each of them, we just call the "free_buffer" procedure       *
 *****************************************************************************/

    free_buf(buf_snd0, &ret )        ; // Free "buf_snd0"
    free_buf(buf_snd1, &ret )        ; // Free "buf_snd1"

  }


/*  Procedure give_asy_token --------------------------------------------------

    Purpose : Give one or more receive token to the ASY driver
*/

static void give_asy_token(int iod, int nbtok, int size, int *count)
  {
    unsigned char   *adr             ; // Adr of allocated buffer (unused)
    int             of7              ; // Firts byte in buffer (unused)
    int             lg               ; // Number of bytes read (unused)
    int             ret              ; // Return code

/*****************************************************************************
 * Step 1 : In order to have data flow control, the application have to      *
 * ------   give to the ASY driver receive tokens. One token is one buffer.  *
 *          The applications gives to the driver a number of tokens "nbtok"  *
 *          and the size "size" of the buffers. The application as to send   *
 *          a REQ_READ request to the VMIO ASY automaton. The buffers are    *
 *          allocated  by the ASY driver (the VMIO AUT_ASY automaton). To    *
 *          send the REQ_READ event, we call "drv_read".                     *
 *          ---------------------------------------------------------------- *
 *          RESP_READ event will be received after data will be received     *
 *          from the asynchronous line. This may take a long time, or may    *
 *          never occure. So we are not going to unschedule right now        *
 *****************************************************************************/

    drv_read(iod       ,               // I/O descriptor for DEV0
             size      ,               // Maximum number of bytes / buffer
             nbtok     ,               // token/buffer number
             0         ,               // Flags
             &adr      ,               // Buffer address (unused)
             &of7      ,               // Offset (unused)
             &lg       ,               // Number of bytes read (unused)
             1         ,               // Reqid
             &ret        )           ; // Return code

    *count += nbtok                  ; // Update token counter

  }


/*  Procedure write_asy  ------------------------------------------------------

    Purpose : Prints (sends) on the serial line one buffer. This is a blocking
              procedure, we are unscheduled until the end of transmission
*/

static void write_asy(int iod, unsigned char *buf, int lg)
  {
    int             ret              ; // Return code

/*****************************************************************************
 * Step 1 : Send using serial controller "iod" the "lg" bytes that are       *
 * ------   in telecom buffer ponted by "buf".  We call the "drv_write"      *
 *          procedure that sends a REQ_WRITE request event to the AUT_ASY    *
 *          VMIO automaton. 
 *****************************************************************************/

    drv_write(iod       ,              // IOD of serial controller DEV0
              buf       ,              // Buffer Address
              0         ,              // Buffer Offset
              lg        ,              // Number of bytes to be sent
              0         ,              // Flags
              1         ,              // Reqid
              &ret       )           ; // Return code


/*****************************************************************************
 * Step 2 : We unschedule until the RESP_WRITE event is received. This event *
 * ------   is sent by AUY_ASY only when the last byte as been sent on the   *
 *          serial line and not before                                       *
 *****************************************************************************/

    wait_coderes(RESP_WRITE,iod)     ; // Unschedule until the RESP_WRITE
                                       // event is received.
  }


/*  Procedure set_asy ---------------------------------------------------------

    Purpose : Sets a parameter of the serial line
*/

static void set_asy(int iod, const char *param)
  {
    int             ret              ; // Return code

/*****************************************************************************
 * Step 1 : We simply send the parameter to the ASY driver, so we call the   *
 * ------   "drv_setval" procedure that sends the REQ_SETVAL event to the    *
 *          VMIO AUT_ASY automaton. The procedure unschedules the task until *
 *          the event RESP_SETVAL is received.                               *
 *****************************************************************************/

    drv_setval(iod                ,    // IOD descriptor of ASY device
               (char*) param      ,    // Taglist as received
               0                  ,    // Reqid
               &ret                ) ; // Return code 

  }



/*  Procedure set_asy1_state --------------------------------------------------

    Purpose : Start/Stop sendin messages on serial line
*/

static void set_asy1_state(void)
  {

/*****************************************************************************
 * Step 1 : If stop is requested, there is nothing to do here. The procedure *
 * ------   "ev_asy1_snd" will be called after each sent message and then we *
 *          will simply not send another message to ASY DEV1.                *
 *****************************************************************************/

    if (state[3] EQ 0)                 // If stop has been requested,
      goto end                       ; // exit from the procedure.


/*****************************************************************************
 * Step 2 : If start has been requested, we want to have at least two        *
 * ------   messages ready to be sent in ASY driver so that there is no      *
 *          time lost between two messages. Variable "msg_snd1" holds the    *
 *          number of messages given to ASY driver. This variable is         *
 *          incremented each time a request is sent to ASY driver and        *
 *          decremented each time a response is received from ASY driver.    *
 *****************************************************************************/

    while (msg_snd1 LT 2)              // Until we have sent enough messages,
      send_asy_msg(asy_iod1 ,          // I/O descriptor
                   buf_snd1 ,          // Address of buffer
                   256      ,          // Number of bytes to send
                   &msg_snd1 )       ; // Number of sending messages

    end                              : // Early exit
    return                           ; // Exit from procedure

  }



/*  Procedure send_asy_msg ----------------------------------------------------

    Purpose : Give one message to the ASY driver. This procedure is
              non-blocking.
*/

static void send_asy_msg(int iod, unsigned char *buf, int lg, int *count)
  {
    int             ret              ; // Return code

/*****************************************************************************
 * Step 1 : Send using serial controller "iod" the "lg" bytes that are       *
 * ------   in telecom buffer ponted by "buf".  We call the "drv_write"      *
 *          procedure that sends a REQ_WRITE request event to the AUT_ASY    *
 *          VMIO automaton. We want to maximize throughput, so we don't wait *
 *          for data ta have been sent here. We therefore don't unschedule.  *
 *****************************************************************************/

    drv_write(iod       ,              // IOD of serial controller DEV0
              buf       ,              // Buffer Address
              0         ,              // Buffer Offset
              lg        ,              // Number of bytes to be sent
              0         ,              // Flags
              1         ,              // Reqid
              &ret       )           ; // Return code

    *count += 1                      ; // Update number of inflight messages

  }


/*  Procedure ev_asy0_snd -----------------------------------------------------

    Purpose : Select the treatment when EV_ASY0_SND event is received.
*/

static int ev_asy0_snd(void)
  { 
    return OPT_IGNORE                ; // Ignore these events
  }



/*  Procedure wait_coderes ----------------------------------------------------

    Purpose : Unschedule until one specific event is received. If non awaited
              events are received meanwhile, they will be kept inside the task
              events waiting queue.
*/

static void wait_coderes(int code, int res)
  {
    int             ret              ; // Return code
    int             waitlist[1][3]   ; // Parameter of "waitevt_task

/*****************************************************************************
 * Step 1 : We build a list of a single pair (code,reserve). The task will   *
 * ------   be unschedule until an event corresponding to the one expected   *
 *          is received by the task. This wait may be infinite if the event  *
 *          is never received.                                               *
 *****************************************************************************/

    waitlist[0][0]  = WAIT_CODERES   ; // Test "code" and "reserve" fields
    waitlist[0][1]  = code           ; // The awaited value for "code"
    waitlist[0][2]  = res            ; // The awaited value for "reserve"

    waitevt_task(waitlist ,            // Address of waiting list
                 1        ,            // Size of "waitlist[]"
                 0        ,            // No maximum waiting time
                 0        ,            // Do not purge previous events
                 &ret       )        ; // Return code
  }


/*  Procedure wait_myevents ---------------------------------------------------

    Purpose : Unschedule until any of my events is received or "msec" seconds
              have been elapsed. A value of 0 for "msec" means no maximum
              time limit. Accordind to the received event, the retourn value
              of this procedure is as follows :

              Code             Reserve        Return value
              ---------------  --------       ---------------
              TICK             any        ->  EV_MSEC       30

              The "ret" value maybe -1 if we receive something else
*/

static int wait_myevents(void)
  {
    int             waitlist[1][3]   ; // Parameter of "waitevt_task
    int             ret              ; // Return code

/*****************************************************************************
 * Step 1 : Build the list of our awaited events and then unschedule until   *
 * ------   one of those is received. The events we are waiting for are :    *
 *          - The TICK event that is received every second. This one is      *
 *            the result of the call to the "set_tto" procedure              *
 *         Then we call the "waitevt_task" procedure that will unschedule us *
 *         until one of the awaited event will be received.                  *
 *****************************************************************************/

    waitlist[0][0]  = WAIT_CODERES   ; // All events with
    waitlist[0][1]  = TICK           ; // an event code TICK
    waitlist[0][2]  = 0              ; // with "reserve" equal to request

    waitevt_task(waitlist ,            // Address of waiting list
                 1        ,            // Size of "waitlist[]"
                 0        ,            // maximum waiting time = no
                 0        ,            // Do not purge previous events
                 &ret       )        ; // Return code


/*****************************************************************************
 * Step 2 : Here we are scheduled again. The VMK has written into its        *
 * ------   global variable "task_evt" a copy of the event that has          *
 *          scheduled us again.                                              *
 *          the VMK generated event TICK (every second). According to the    *
 *          value of "task_evt.code" but also "task_evt.reserve" we compute  *
 *          the return value "ret". If we receive something we are not       *
 *          expecting, we will return a default value of -1.                 *
 *****************************************************************************/

    ret = -1                         ; // received event.

    switch ( task_evt.code )
      {
        case TICK                    : // For a TICK, the "reserve"
          ret = EV_MSEC              ; // field is a copy of the one received
          break                      ; // and we don't care.

        default                      : // This should never occur if there
          break                      ; // is no bug.
      }

    return ret                       ;

  }

/*  Procedure print_time ------------------------------------------------------

    Purpose : Prints (sends) on the serial line the current time in seconds
*/

static void print_time(void)
  {
    int             d, m, y          ; // Day, Month, Year
    int             h, mi, s, ms     ; // Hour, minutes, seconds, milliseconds
    int             lg               ; // Number of bytes to be sent

/*****************************************************************************
 * Step 1 : We first retrieve date and time since boot.                      *
 * ------                                                                    *
 *****************************************************************************/

    tim_get(&d  ,                      // day
            &m  ,                      // Month
            &y  ,                      // Year
            &h  ,                      // Hour (0..23)
            &mi ,                      // Minutes (0..59)
            &s  ,                      // Seconds (0..59)
            &ms   )                  ; // Milliseconds (0..999)

    hsprintf((char*)buf_snd0  ,        // Put in the transmit buffer
    "Hello World since :%02d:%02d:%02d\n\r" ,    //  HH:MM:SS
             h, mi, s              ) ; //
    lg = strlen ((char*)buf_snd0   ) ; // size of the time string 


/*****************************************************************************
 * Step 2 : Send using serial DEV0, so IOD "asy_iod0", the "lg" characters   *
 * ------   that are in the buffer pointed by "buf_snd0". We call the        *
 *          "drv_write" procedure that sends a REQ_WRITE request event to    *
 *          the AUT_ASY VMIO automaton. The we unschedule until the          *
 *          RESP_WRITE response event is received                            *
 *****************************************************************************/

    write_asy(asy_iod0  ,              // I/O descriptor for ASY\DEV0
              buf_snd0  ,              // Address of buffer
              lg         )           ; // Number of bytes to be sent
  }

